import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { SisenseContextService, ThemeService } from '@sisense/sdk-ui-angular';
import { type ChatbotProps as ChatbotPropsPreact } from '@sisense/sdk-ui-preact/ai';
import { AiService } from '../services/ai.service';
import * as i0 from "@angular/core";
/**
 * Props of the {@link ChatbotComponent}.
 */
export interface ChatbotProps extends ChatbotPropsPreact {
}
/**
 * An Angular component that renders a chatbot with data topic selection.
 *
 * @example
 * An example of using the `ChatbotComponent`:
 *
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-chatbot
  [width]="chatbot.width"
  [height]="chatbot.height"
  [config]="chatbot.config"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  chatbot = {
    width: '500px',
    height: '700px',
    config: {
      numOfRecommendations: 5,
    },
  };
}
 * ```
 *
 * <img src="media://angular-chatbot-example.png" width="500px" />
 * @group Generative AI
 */
export declare class ChatbotComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * AI service
     *
     * @category Constructor
     */
    aiService: AiService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChatbotProps.width}
     */
    width: ChatbotProps['width'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChatbotProps.height}
     */
    height: ChatbotProps['height'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChatbotProps.config}
     */
    config: ChatbotProps['config'];
    private componentAdapter;
    /**
     * Constructor for the `ChatbotComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     * @param aiService - AI service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService, 
    /**
     * AI service
     *
     * @category Constructor
     */
    aiService: AiService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChatbotComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChatbotComponent, "csdk-chatbot", never, { "width": "width"; "height": "height"; "config": "config"; }, {}, never, never, false, never>;
}
