import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { SisenseContextService, ThemeService } from '@sisense/sdk-ui-angular';
import { type GetNlgInsightsProps as GetNlgInsightsPropsPreact } from '@sisense/sdk-ui-preact/ai';
import { AiService } from '../services/ai.service';
import * as i0 from "@angular/core";
/**
 * Props of the {@link GetNlgInsightsComponent}.
 */
export interface GetNlgInsightsProps extends GetNlgInsightsPropsPreact {
}
/**
 * An Angular component that fetches and displays a collapsible analysis of the provided query using natural language generation (NLG).
 * Specifying NLG parameters is similar to providing parameters to the {@link QueryService.executeQuery} service method, using dimensions, measures, and filters.
 *
 * @example
 * An example of using the `GetNlgInsightsComponent`:
 *
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-get-nlg-insights
  [dataSource]="nlgParams.dataSource"
  [dimensions]="nlgParams.dimensions"
  [measures]="nlgParams.measures"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';
import { measureFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  nlgParams = {
    dataSource: DM.DataSource.title,
    dimensions: [DM.Divisions.Divison_name],
    measures: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
  };
}
 * ```
 *
 * <img src="media://angular-get-nlg-insights-example.png" width="700px" />
 * @group Generative AI
 */
export declare class GetNlgInsightsComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * AI service
     *
     * @category Constructor
     */
    aiService: AiService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!GetNlgInsightsProps.dataSource}
     */
    dataSource: GetNlgInsightsProps['dataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!GetNlgInsightsProps.dimensions}
     */
    dimensions: GetNlgInsightsProps['dimensions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!GetNlgInsightsProps.measures}
     */
    measures: GetNlgInsightsProps['measures'];
    /**
     * {@inheritDoc @sisense/sdk-ui!GetNlgInsightsProps.filters}
     */
    filters: GetNlgInsightsProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!GetNlgInsightsProps.verbosity}
     */
    verbosity: GetNlgInsightsProps['verbosity'];
    private componentAdapter;
    /**
     * Constructor for the `GetNlgInsightsProps`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     * @param aiService - AI service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService, 
    /**
     * AI service
     *
     * @category Constructor
     */
    aiService: AiService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<GetNlgInsightsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GetNlgInsightsComponent, "csdk-get-nlg-insights", never, { "dataSource": "dataSource"; "dimensions": "dimensions"; "measures": "measures"; "filters": "filters"; "verbosity": "verbosity"; }, {}, never, never, false, never>;
}
