import { EventEmitter } from '@angular/core';
import { type AreamapChartProps as AreamapChartPropsPreact, type ChartType } from '@sisense/sdk-ui-preact';
import { AreamapChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { AreamapDataPointEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link AreamapChartComponent}.
 */
export interface AreamapChartProps extends WithoutPreactChartEventProps<AreamapChartPropsPreact>, AreamapChartEventProps {
}
/**
 * An Angular component that allows to visualize geographical data as polygons on a map.
 *
 * @example
 * ```html
 *    <csdk-areamap-chart
 *      [dataSet]="areamapChart.dataSet"
 *      [dataOptions]="areamapChart.dataOptions"
 *      [styleOptions]="areamapChart.styleOptions"
 *      (dataPointClick)="logArguments($event)"
 *    />
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import { measureFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-ecommerce';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  areamapChart = {
    dataSet: DM.DataSource,
    dataOptions: {
      geo: [DM.Country.Country],
      color: [measureFactory.sum(DM.Commerce.Revenue, 'Color by Revenue')],
    } as AreamapChartDataOptions,
    styleOptions: {
      mapType: 'world',
    } as AreamapStyleOptions,
  };

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-areamap-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class AreamapChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!AreamapChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: AreamapChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreamapChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: AreamapChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreamapChartProps.filters}
     *
     * @category Data
     */
    filters: AreamapChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreamapChartProps.highlights}
     *
     * @category Data
     */
    highlights: AreamapChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreamapChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: AreamapChartProps['styleOptions'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!AreamapChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: AreamapChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreamapChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<AreamapDataPointEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<AreamapChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AreamapChartComponent, "csdk-areamap-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; }, never, never, false, never>;
}
