import { type IndicatorChartProps as IndicatorChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { IndicatorChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import * as i0 from "@angular/core";
/**
 * Props of the {@link IndicatorChartComponent}.
 */
export interface IndicatorChartProps extends WithoutPreactChartEventProps<IndicatorChartPropsPreact>, IndicatorChartEventProps {
}
/**
 * A component that provides various options for displaying one or two numeric values as a number, gauge or ticker.
 *
 * @example
 * ```html
 *    <csdk-indicator-chart
 *      [dataSet]="indicator.dataSet"
 *      [dataOptions]="indicator.dataOptions"
 *      [filters]="filters"
 *      [styleOptions]="indicator.styleOptions"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { IndicatorStyleOptions } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  indicator = {
    dataSet: DM.DataSource,
    dataOptions: {
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      secondary: [measureFactory.sum(DM.Admissions.Diagnosis_ID)],
    },
    styleOptions: {
      indicatorComponents: {
        title: {
          shouldBeShown: true,
          text: 'Total Cost_of_admission',
        },
        secondaryTitle: {
          text: 'Total Diagnosis_ID',
        },
        ticks: {
          shouldBeShown: true,
        },
        labels: {
          shouldBeShown: true,
        },
      },
      subtype: 'indicator/gauge',
      skin: 2,
    } as IndicatorStyleOptions,
  };

}
 * ```
 * <img src="media://angular-indicator-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class IndicatorChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!IndicatorChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: IndicatorChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!IndicatorChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: IndicatorChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!IndicatorChartProps.filters}
     *
     * @category Data
     */
    filters: IndicatorChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!IndicatorChartProps.highlights}
     *
     * @category Data
     */
    highlights: IndicatorChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!IndicatorChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: IndicatorChartProps['styleOptions'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!IndicatorChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: IndicatorChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!IndicatorChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: IndicatorChartProps['dataReady'];
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<IndicatorChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IndicatorChartComponent, "csdk-indicator-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, {}, never, never, false, never>;
}
