import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { type PivotTableProps as PivotTablePropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services';
import { ThemeService } from '../../services';
import * as i0 from "@angular/core";
/**
 * Props of the {@link PivotTableComponent}.
 */
export interface PivotTableProps extends PivotTablePropsPreact {
}
/**
 * Pivot Table with and pagination.
 *
 * @example
 * ```html
 *  <csdk-pivot-table
 *    [dataSet]="pivotTable.dataSet"
 *    [dataOptions]="pivotTable.dataOptions"
 *    [filters]="pivotTable.filters"
 *    [styleOptions]="pivotTable.styleOptions"
 *  />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-ecommerce';
import type { PivotTableDataOptions } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {

  pivotTableDataOptions: PivotTableDataOptions = {
    rows: [
      { column: DM.Category.Category, includeSubTotals: true },
      { column: DM.Commerce.AgeRange, includeSubTotals: true },
      DM.Commerce.Condition,
    ],
    columns: [{ column: DM.Commerce.Gender, includeSubTotals: true }],
    values: [
      measureFactory.sum(DM.Commerce.Cost, 'Total Cost'),
      {
        column: measureFactory.sum(DM.Commerce.Revenue, 'Total Revenue'),
        totalsCalculation: 'sum',
        dataBars: true,
      },
    ],
    grandTotals: { title: 'Grand Total', rows: true, columns: true },
  };

  pivotTable = {
    dataSet: DM.DataSource,
    dataOptions: this.pivotTableDataOptions,
    filters: [filterFactory.members(DM.Commerce.Gender, ['Female', 'Male'])],
    styleOptions: { width: 1400, height: 600, rowsPerPage: 50 },
  };

}
 * ```
 * <img src="media://angular-pivot-table-example.png" width="800px" />
 * @group Data Grids
 * @beta
 */
export declare class PivotTableComponent implements AfterViewInit, OnChanges, OnDestroy {
    private sisenseContextService;
    private themeService;
    /** @internal */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableProps.dataSet}
     *
     * @category Data
     */
    dataSet: PivotTableProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableProps.dataOptions}
     *
     * @category Data
     */
    dataOptions: PivotTableProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableProps.filters}
     *
     * @category Data
     */
    filters: PivotTableProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableProps.highlights}
     *
     * @category Data
     */
    highlights: PivotTableProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableProps.styleOptions}
     *
     * @category Representation
     */
    styleOptions: PivotTableProps['styleOptions'];
    private componentAdapter;
    constructor(sisenseContextService: SisenseContextService, themeService: ThemeService);
    /** @internal */
    ngAfterViewInit(): void;
    /** @internal */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /** @internal */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PivotTableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PivotTableComponent, "csdk-pivot-table", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; }, {}, never, never, false, never>;
}
