import { EventEmitter } from '@angular/core';
import { type ScattermapChartProps as ScattermapChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { ScattermapChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { ScattermapDataPointEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link ScattermapChartComponent}.
 */
export interface ScattermapChartProps extends WithoutPreactChartEventProps<ScattermapChartPropsPreact>, ScattermapChartEventProps {
}
/**
 * An Angular component that allows to visualize geographical data as data points on a map.
 *
 * @example
 * ```html
 *    <csdk-scattermap-chart
 *      [dataSet]="scattermapChart.dataSet"
 *      [dataOptions]="scattermapChart.dataOptions"
 *      [styleOptions]="scattermapChart.styleOptions"
 *      (dataPointClick)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import type { ScattermapStyleOptions,ScattermapChartDataOptions } from '@sisense/sdk-ui-angular';
import * as DM from '../../assets/sample-ecommerce';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  scattermapChart = {
    dataSet: DM.DataSource,
    dataOptions: {
      geo: [DM.Country.Country],
      size: measureFactory.sum(DM.Commerce.Cost, 'Size by Cost'),
      colorBy: {
        column: measureFactory.sum(DM.Commerce.Revenue, 'Color by Revenue'),
        color: 'green',
      },
      details: DM.Category.Category,
    } as ScattermapChartDataOptions,
    styleOptions: {
      markers: {
        fill: 'hollow-bold',
      },
    } as ScattermapStyleOptions,
  };

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-scattermap-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class ScattermapChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!ScattermapChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: ScattermapChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ScattermapChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: ScattermapChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ScattermapChartProps.filters}
     *
     * @category Data
     */
    filters: ScattermapChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ScattermapChartProps.highlights}
     *
     * @category Data
     */
    highlights: ScattermapChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ScattermapChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: ScattermapChartProps['styleOptions'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!ScattermapChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: ScattermapChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ScattermapChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<ScattermapDataPointEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<ScattermapChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ScattermapChartComponent, "csdk-scattermap-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; }, never, never, false, never>;
}
