import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { type TableProps as TablePropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import { BaseChartEventProps, WithoutPreactChartEventProps } from '../../types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link TableComponent}.
 */
export interface TableProps extends WithoutPreactChartEventProps<TablePropsPreact>, BaseChartEventProps {
}
/**
 * Table with aggregation and pagination.
 *
 * @example
 * ```html
 *  <csdk-table [dataSet]="table.dataSet" [dataOptions]="table.dataOptions" [filters]="filters" />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  table = {
    dataSet: DM.DataSource,
    dataOptions: {
      columns: [DM.Admissions.Patient_ID, measureFactory.sum(DM.Admissions.Cost_of_admission)],
    },
  };

}
 * ```
 * <img src="media://angular-table-chart-example.png" width="800px" />
 * @group Data Grids
 */
export declare class TableComponent implements AfterViewInit, OnChanges, OnDestroy {
    private sisenseContextService;
    private themeService;
    /** @internal */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!TableProps.dataSet}
     *
     * @category Data
     */
    dataSet: TableProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableProps.dataOptions}
     *
     * @category Data
     */
    dataOptions: TableProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableProps.filters}
     *
     * @category Data
     */
    filters: TableProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableProps.styleOptions}
     *
     * @category Representation
     */
    styleOptions: TableProps['styleOptions'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!TableProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: TableProps['dataReady'];
    private componentAdapter;
    constructor(sisenseContextService: SisenseContextService, themeService: ThemeService);
    /** @internal */
    ngAfterViewInit(): void;
    /** @internal */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /** @internal */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableComponent, "csdk-table", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "styleOptions": "styleOptions"; "dataReady": "dataReady"; }, {}, never, never, false, never>;
}
