import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type ContextMenuProps } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../services/sisense-context.service';
import { ThemeService } from '../services/theme.service';
import type { ArgumentsAsObject } from '../types/utility-types';
import * as i0 from "@angular/core";
/**
 * Context Menu Component
 *
 * @group Drilldown
 */
export declare class ContextMenuComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * @internal
     */
    preactContentRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ContextMenuProps.position}
     */
    position: ContextMenuProps['position'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ContextMenuProps.itemSections}
     */
    itemSections: ContextMenuProps['itemSections'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ContextMenuProps.closeContextMenu}
     */
    contextMenuClose: EventEmitter<ArgumentsAsObject<() => void, []>>;
    private componentAdapter;
    /**
     * Constructor for the `ContextMenuComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ContextMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ContextMenuComponent, "csdk-context-menu", never, { "position": "position"; "itemSections": "itemSections"; }, { "contextMenuClose": "contextMenuClose"; }, never, ["*"], false, never>;
}
