import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { type DashboardByIdProps as DashboardByIdPropsPreact } from '@sisense/sdk-ui-preact';
import { PluginsService } from '../../services/plugins.service';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import type { DashboardByIdConfig } from '../../types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link DashboardByIdComponent}.
 */
export interface DashboardByIdProps extends DashboardByIdPropsPreact {
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardByIdProps.config}
     */
    config?: DashboardByIdConfig;
}
/**
 * An Angular component used for easily rendering a dashboard by its ID created in a Sisense Fusion instance.
 *
 * **Note:** Dashboard and Widget extensions based on JS scripts and add-ons in Fusion – for example, Blox and Jump To Dashboard – are not supported.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * @Component({
 *   selector: 'code-example',
 *   template: `
 *     <div style="width: 100vw;">
 *       <csdk-dashboard-by-id *ngIf="dashboardOid" [dashboardOid]="dashboardOid" />
 *     </div>
 *   `,
 *  })
 * export class CodeExampleComponent {
 *   dashboardOid = 'your-dashboard-oid';
 * }
 * ```
 *
 * To learn more about this and related dashboard components,
 * see [Embedded Dashboards](/guides/sdk/guides/dashboards/index.html).
 * @group Fusion Assets
 * @fusionEmbed
 */
export declare class DashboardByIdComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * Plugin service
     *
     * @internal
     * @category Constructor
     */
    pluginService: PluginsService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardByIdProps.dashboardOid}
     */
    dashboardOid: DashboardByIdProps['dashboardOid'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardByIdProps.config}
     */
    config: DashboardByIdProps['config'];
    private componentAdapter;
    /**
     * Constructor for the `DashboardById` component.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService, 
    /**
     * Plugin service
     *
     * @internal
     * @category Constructor
     */
    pluginService: PluginsService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DashboardByIdComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DashboardByIdComponent, "csdk-dashboard-by-id", never, { "dashboardOid": "dashboardOid"; "config": "config"; }, {}, never, never, false, never>;
}
