import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type DrilldownBreadcrumbsProps as DrilldownBreadcrumbsPropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../services/sisense-context.service';
import { ThemeService } from '../services/theme.service';
import type { Arguments, ArgumentsAsObject } from '../types/utility-types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link DrilldownBreadcrumbsComponent}.
 */
export interface DrilldownBreadcrumbsProps extends Omit<DrilldownBreadcrumbsPropsPreact, 'clearDrilldownSelections'> {
    drilldownSelectionsClear?: () => void;
    drilldownSelectionsSlice?: (event: {
        i: Arguments<DrilldownBreadcrumbsPropsPreact['sliceDrilldownSelections']>[0];
    }) => void;
}
/**
 * Drilldown Breadcrumbs Component
 *
 * @group Drilldown
 */
export declare class DrilldownBreadcrumbsComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!DrilldownBreadcrumbsProps.filtersDisplayValues}
     *
     * @category Widget
     */
    filtersDisplayValues: DrilldownBreadcrumbsProps['filtersDisplayValues'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DrilldownBreadcrumbsProps.currentDimension}
     *
     * @category Widget
     */
    currentDimension: DrilldownBreadcrumbsProps['currentDimension'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DrilldownBreadcrumbsProps.clearDrilldownSelections}
     *
     * @category Widget
     */
    drilldownSelectionsClear: EventEmitter<ArgumentsAsObject<() => void, []>>;
    /**
     * {@inheritDoc @sisense/sdk-ui!DrilldownBreadcrumbsProps.sliceDrilldownSelections}
     *
     * @category Widget
     */
    drilldownSelectionsSlice: EventEmitter<number>;
    private componentAdapter;
    /**
     * Constructor for the `DrilldownBreadcrumbsComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DrilldownBreadcrumbsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DrilldownBreadcrumbsComponent, "csdk-drilldown-breadcrumbs", never, { "filtersDisplayValues": "filtersDisplayValues"; "currentDimension": "currentDimension"; }, { "drilldownSelectionsClear": "drilldownSelectionsClear"; "drilldownSelectionsSlice": "drilldownSelectionsSlice"; }, never, never, false, never>;
}
