import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type MemberFilterTileProps as MemberFilterTilePropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import type { Arguments, ArgumentsAsObject } from '../../types/utility-types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link MemberFilterTileComponent}.
 */
export interface MemberFilterTileProps extends Omit<MemberFilterTilePropsPreact, 'onChange'> {
    filterChange?: (filter: Arguments<MemberFilterTilePropsPreact['onChange']>[0]) => void;
}
/**
 * Member Filter Tile Component
 *
 * @example
 * ```html
 *     <csdk-member-filter-tile
 *       title="Years Filter"
 *       [attribute]="DM.ER.Date.Years"
 *       [filter]="memberFilterTileProps.yearFilter"
 *       (filterChange)="memberFilterTileProps.setYearFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;
 *   memberFilterTileProps = {
 *     yearFilter: filterFactory.members(DM.ER.Date.Years, ['2013-01-01T00:00:00']),
 *     setYearFilter({ filter }: { filter: Filter | null }) {
 *       if (filter) {
 *         this.yearFilter = filter;
 *       }
 *     },
 *   };
 * }
 * ```
 * <img src="media://angular-member-filter-tile-example.png" width="225px" />
 * @group Filter Tiles
 */
export declare class MemberFilterTileComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!MemberFilterTileProps.title}
     */
    title: MemberFilterTileProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!MemberFilterTileProps.dataSource}
     */
    dataSource: MemberFilterTileProps['dataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!MemberFilterTileProps.attribute}
     */
    attribute: MemberFilterTileProps['attribute'];
    /**
     * {@inheritDoc @sisense/sdk-ui!MemberFilterTileProps.filter}
     */
    filter: MemberFilterTileProps['filter'];
    /**
     * {@inheritDoc @sisense/sdk-ui!MemberFilterTileProps.onChange}
     */
    filterChange: EventEmitter<ArgumentsAsObject<(filter: import("@sisense/sdk-data").Filter | null) => void, ["filter"]>>;
    private componentAdapter;
    /**
     * Constructor for the `MemberFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MemberFilterTileComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MemberFilterTileComponent, "csdk-member-filter-tile", never, { "title": "title"; "dataSource": "dataSource"; "attribute": "attribute"; "filter": "filter"; }, { "filterChange": "filterChange"; }, never, never, false, never>;
}
