import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type RelativeDateFilterTileProps as RelativeDateFilterTilePropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import type { Arguments, ArgumentsAsObject } from '../../types/utility-types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link RelativeDateFilterTileComponent}.
 */
export interface RelativeDateFilterTileProps extends Omit<RelativeDateFilterTilePropsPreact, 'onUpdate'> {
    filterChange?: (filter: Arguments<RelativeDateFilterTilePropsPreact['onUpdate']>[0]) => void;
}
/**
 * Relative Date Filter Tile Component
 *
 * @example
 * ```html
 * <csdk-relative-date-filter-tile
 *       [title]="relativeDateFilterTileProps.title"
 *       [arrangement]="relativeDateFilterTileProps.arrangement"
 *       [filter]="relativeDateFilterTileProps.filter"
 *       (filterChange)="relativeDateFilterTileProps.setFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;
 *
 *   relativeDateFilterTileProps = {
 *     title: 'Relative Date Filter',
 *     arrangement: 'vertical',
 *     filter: filterFactory.dateRelativeTo(DM.ER.Date.Days, 0, 150),
 *     setFilter({ filter }: { filter: Filter | null }) {
 *       console.log(filter);
 *       if (filter) {
 *         this.filter = filter;
 *       }
 *     },
 *   };
 * }
 * ```
 * <img src="media://angular-relative-date-filter-tile-example.png" width="600px" />
 * @group Filter Tiles
 */
export declare class RelativeDateFilterTileComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!RelativeDateFilterTileProps.title}
     */
    title: RelativeDateFilterTileProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!RelativeDateFilterTileProps.filter}
     */
    filter: RelativeDateFilterTileProps['filter'];
    /**
     * {@inheritDoc @sisense/sdk-ui!RelativeDateFilterTileProps.arrangement}
     */
    arrangement: RelativeDateFilterTileProps['arrangement'];
    /**
     * {@inheritDoc @sisense/sdk-ui!RelativeDateFilterTileProps.limit}
     */
    limit: RelativeDateFilterTileProps['limit'];
    /**
     * {@inheritDoc @sisense/sdk-ui!RelativeDateFilterTileProps.onUpdate}
     */
    filterChange: EventEmitter<ArgumentsAsObject<(filter: import("@sisense/sdk-data").Filter) => void, ["filter"]>>;
    private componentAdapter;
    /**
     * Constructor for the `RelativeDateFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RelativeDateFilterTileComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RelativeDateFilterTileComponent, "csdk-relative-date-filter-tile", never, { "title": "title"; "filter": "filter"; "arrangement": "arrangement"; "limit": "limit"; }, { "filterChange": "filterChange"; }, never, never, false, never>;
}
