import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { type TableWidgetProps as TableWidgetPropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import * as i0 from "@angular/core";
/**
 * Props of the {@link TableWidgetComponent}.
 *
 * @internal
 */
export interface TableWidgetProps extends TableWidgetPropsPreact {
}
/**
 * The Table Widget component extending {@link TableComponent} component to support widget style options.
 *
 * @example
 * ```html
 *  <csdk-table-widget
 *    [dataSource]="table.dataSet"
 *    [dataOptions]="table.dataOptions"
 *    [filters]="filters"
 *    [title]="table.title"
 *    [description]="table.description"
 *  />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { ChartType } from '@sisense/sdk-ui-angular';
 * import { filterFactory, measureFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *  selector: 'app-widgets',
 * templateUrl: './widgets.component.html',
 * styleUrls: ['./widgets.component.scss'],
 * })
 * export class WidgetsComponent {
 * filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
 *
 * table = {
 *    dataSet: DM.DataSource,
 *    dataOptions: {
 *      columns: [DM.Admissions.Patient_ID, measureFactory.sum(DM.Admissions.Cost_of_admission)],
 *    }
 *    title: 'Widget Title',
 *    description: 'Widget Description',
 *  };
 * }
 * ```
 * <img src="media://angular-table-widget-example.png" width="800px" />
 * @internal
 */
export declare class TableWidgetComponent implements AfterViewInit, OnChanges, OnDestroy {
    private sisenseContextService;
    private themeService;
    /** @internal */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!TableWidgetProps.dataSource}
     *
     * @category Data
     */
    dataSource: TableWidgetProps['dataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableWidgetProps.dataOptions}
     *
     * @category Data
     */
    dataOptions: TableWidgetProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableWidgetProps.filters}
     *
     * @category Data
     */
    filters: TableWidgetProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableWidgetProps.styleOptions}
     *
     * @category Representation
     */
    styleOptions: TableWidgetProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableWidgetProps.title}
     *
     * @category Widget
     */
    title: TableWidgetProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!TableWidgetProps.description}
     *
     * @category Widget
     */
    description: TableWidgetProps['description'];
    private componentAdapter;
    constructor(sisenseContextService: SisenseContextService, themeService: ThemeService);
    ngAfterViewInit(): void;
    ngOnChanges(): void;
    private getPreactComponentProps;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableWidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableWidgetComponent, "csdk-table-widget", never, { "dataSource": "dataSource"; "dataOptions": "dataOptions"; "filters": "filters"; "styleOptions": "styleOptions"; "title": "title"; "description": "description"; }, {}, never, never, false, never>;
}
