import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { type WidgetByIdProps as WidgetByIdPropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import { BaseChartEventProps, WithoutPreactChartEventProps } from '../../types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link WidgetByIdComponent}.
 */
export interface WidgetByIdProps extends WithoutPreactChartEventProps<WidgetByIdPropsPreact>, BaseChartEventProps {
}
/**
 * The `WidgetById` component, which is a thin wrapper on {@link ChartWidgetComponent},
 * is used to render a widget created in a Sisense Fusion instance.
 *
 * To learn more about using Sisense Fusion Widgets in Compose SDK, see
 * [Sisense Fusion Widgets](https://sisense.dev/guides/sdk/guides/charts/guide-fusion-widgets.html).
 *
 * @example
 * ```html
 * <csdk-widget-by-id
 *    [widgetOid]="widgetOid"
 *    [dashboardOid]="dashboardOid"
 *    [includeDashboardFilters]="true"
 * />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 *
 * @Component({
 *  selector: 'app-widgets',
 *  templateUrl: './widgets.component.html',
 *  styleUrls: ['./widgets.component.scss'],
 * })
 * export class WidgetsComponent {
 *  widgetOid: string = '60f3e3e3e4b0e3e3e4b0e3e3';
 *  dashboardOid: string = '60f3e3e3e4b0e3e3e4b0e3e3';
 * }
 * ```
 * @group Fusion Assets
 * @fusionEmbed
 */
export declare class WidgetByIdComponent implements AfterViewInit, OnChanges, OnDestroy {
    private sisenseContextService;
    private themeService;
    /** @internal */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.widgetOid}
     *
     * @category Widget
     */
    widgetOid: WidgetByIdProps['widgetOid'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.dashboardOid}
     *
     * @category Widget
     */
    dashboardOid: WidgetByIdProps['dashboardOid'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.filters}
     *
     * @category Data
     */
    filters: WidgetByIdProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.highlights}
     *
     * @category Data
     */
    highlights: WidgetByIdProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.filtersMergeStrategy}
     *
     * @category Data
     */
    filtersMergeStrategy: WidgetByIdProps['filtersMergeStrategy'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.includeDashboardFilters}
     *
     * @category Data
     */
    includeDashboardFilters: WidgetByIdProps['includeDashboardFilters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.title}
     *
     * @category Widget
     */
    title: WidgetByIdProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.description}
     *
     * @category Widget
     */
    description: WidgetByIdProps['description'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.styleOptions}
     *
     * @category Widget
     */
    styleOptions: WidgetByIdProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!WidgetByIdProps.highlightSelectionDisabled}
     *
     * @category Widget
     */
    highlightSelectionDisabled: WidgetByIdProps['highlightSelectionDisabled'];
    /** @internal */
    drilldownOptions: WidgetByIdProps['drilldownOptions'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!WidgetByIdProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: WidgetByIdProps['dataReady'];
    private componentAdapter;
    constructor(sisenseContextService: SisenseContextService, themeService: ThemeService);
    /** @internal */
    ngAfterViewInit(): void;
    /** @internal */
    ngOnChanges(): void;
    /** @internal */
    private getPreactComponentProps;
    /** @internal */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<WidgetByIdComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WidgetByIdComponent, "csdk-widget-by-id", never, { "widgetOid": "widgetOid"; "dashboardOid": "dashboardOid"; "filters": "filters"; "highlights": "highlights"; "filtersMergeStrategy": "filtersMergeStrategy"; "includeDashboardFilters": "includeDashboardFilters"; "title": "title"; "description": "description"; "styleOptions": "styleOptions"; "highlightSelectionDisabled": "highlightSelectionDisabled"; "drilldownOptions": "drilldownOptions"; "dataReady": "dataReady"; }, {}, never, never, false, never>;
}
