import { PluginComponent } from '@sisense/sdk-ui-preact';
import { BehaviorSubject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Service for working with plugins fetched from an external environment.
 *
 * Provides methods for registering, retrieving, and interacting with plugins.
 *
 * @internal
 * @group Contexts
 */
export declare class PluginsService {
    private pluginMap$;
    constructor();
    /**
     * Registers a new plugin into the plugin map.
     *
     * @param pluginType - The unique identifier for the plugin type.
     * @param plugin - The plugin instance to register.
     */
    registerPlugin(pluginType: string, plugin: PluginComponent): void;
    /**
     * Retrieves a plugin by its type.
     *
     * @param pluginType - The unique identifier for the plugin type.
     * @returns The plugin instance if found, otherwise undefined.
     */
    getPlugin(pluginType: string): PluginComponent | undefined;
    /**
     * Retrieves a complete plugin map.
     *
     * @returns A plugin map.
     */
    getPlugins(): BehaviorSubject<Map<string, PluginComponent<import("@sisense/sdk-ui-preact").PluginComponentProps<import("@sisense/sdk-ui-preact").GenericDataOptions, any>>>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PluginsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PluginsService>;
}
