import { type ExecuteCsvQueryParams as ExecuteCsvQueryParamsPreact, type ExecutePivotQueryParams as ExecutePivotQueryParamsPreact, type ExecuteQueryByWidgetIdParams as ExecuteQueryByWidgetIdParamsPreact, type ExecuteQueryParams as ExecuteQueryParamsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from './sisense-context.service';
import * as i0 from "@angular/core";
interface ExecuteQueryHandlers {
    /** Sync or async callback that allows to modify the JAQL payload before it is sent to the server. */
    beforeQuery?: ExecuteQueryParamsPreact['onBeforeQuery'];
}
/**
 * Parameters for data query execution.
 */
export interface ExecuteQueryParams extends Omit<ExecuteQueryParamsPreact, 'enabled' | 'onBeforeQuery'>, ExecuteQueryHandlers {
}
/**
 * Parameters for data query by widget id execution.
 */
export interface ExecuteQueryByWidgetIdParams extends Omit<ExecuteQueryByWidgetIdParamsPreact, 'enabled' | 'onBeforeQuery'>, ExecuteQueryHandlers {
}
/**
 * Parameters for pivot data query execution.
 */
export interface ExecutePivotQueryParams extends Omit<ExecutePivotQueryParamsPreact, 'enabled' | 'onBeforeQuery'>, ExecuteQueryHandlers {
}
/**
 * Parameters for CSV data query execution.
 */
export interface ExecuteCsvQueryParams extends Omit<ExecuteCsvQueryParamsPreact, 'enabled' | 'onBeforeQuery'>, ExecuteQueryHandlers {
}
/**
 * Service for executing data queries.
 *
 * @group Queries
 */
export declare class QueryService {
    private sisenseContextService;
    constructor(sisenseContextService: SisenseContextService);
    /**
     * Executes a data query. If you want to display the query results, you can use
     * them to populate Compose SDK UI elements or third party UI elements.
     *
     * To learn how to populate third party UI elements with query results, see the
     * [External Charts Guide](/guides/sdk/guides/charts/guide-external-charts.html#query)
     *
     * @param params - Query parameters
     * @return Query result
     */
    executeQuery(params: ExecuteQueryParams): Promise<{
        data: import("@sisense/sdk-data").QueryResultData;
    }>;
    /**
     * Executes a data query extracted from an existing widget in the Sisense instance.
     *
     * @param params - Parameters to identify the target widget
     * @returns Query result
     */
    executeQueryByWidgetId(params: ExecuteQueryByWidgetIdParams): Promise<{
        data: import("@sisense/sdk-data").QueryResultData;
    } & import("@sisense/sdk-ui-preact").QueryByWidgetIdQueryParams>;
    /**
     * Executes a data query for a pivot table.
     *
     * @param params - Pivot query parameters
     * @return Pivot query result
     * @beta
     */
    executePivotQuery(params: ExecutePivotQueryParams): Promise<{
        data: import("@sisense/sdk-data").PivotQueryResultData;
    }>;
    /**
     * Executes a CSV data query.
     * Similar to {@link QueryService.executeQuery}, but returns the data in CSV format as text or as a stream.
     *
     * @param params - CSV query parameters
     * @return CSV query result
     */
    executeCsvQuery(params: ExecuteCsvQueryParams): Promise<{
        data: Blob | string;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<QueryService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<QueryService>;
}
export {};
