import { InjectionToken } from '@angular/core';
import type { SisenseContextProviderProps as SisenseContextConfig } from '@sisense/sdk-ui-preact';
import { ClientApplication } from '@sisense/sdk-ui-preact';
import * as i0 from "@angular/core";
export { type SisenseContextConfig };
/**
 * Token used to inject {@link SisenseContextConfig} into your application
 *
 * @example
 * Example of importing {@link SdkUiModule} and injecting {@link SisenseContextConfig} into your application:
 *
 * ```ts
 * export const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Contexts
 */
export declare const SISENSE_CONTEXT_CONFIG_TOKEN: InjectionToken<SisenseContextConfig>;
/**
 * Service for working with Sisense Fusion context.
 *
 * @group Contexts
 */
export declare class SisenseContextService {
    private appPromise;
    private config;
    constructor(sisenseContextConfig: SisenseContextConfig);
    /** @internal */
    getApp(): Promise<ClientApplication>;
    getConfig(): SisenseContextConfig;
    static ɵfac: i0.ɵɵFactoryDeclaration<SisenseContextService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SisenseContextService>;
}
