import { InjectionToken } from '@angular/core';
import { type CompleteThemeSettings, type ThemeProviderProps as ThemeConfig } from '@sisense/sdk-ui-preact';
import { type ThemeSettings } from '../sdk-ui-core-exports';
import { SisenseContextService } from './sisense-context.service';
import * as i0 from "@angular/core";
export { type ThemeConfig };
/**
 * Token used to inject {@link ThemeConfig} into your application
 *
 * @example
 *
 * Example of injecting both {@link SisenseContextConfig} and {@link ThemeConfig} into your application:
 *
 * ```ts
 * export const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *     {
 *       provide: THEME_CONFIG_TOKEN,
 *       useValue: {
 *         // initial theme settings
 *       } as ThemeConfig,
 *     },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Contexts
 */
export declare const THEME_CONFIG_TOKEN: InjectionToken<ThemeConfig>;
/**
 * Service for working with Sisense Fusion themes.
 *
 * If no theme service is used, the current Fusion theme is applied by default.
 *
 * @group Contexts
 */
export declare class ThemeService {
    private sisenseContextService;
    private themeSettings$;
    constructor(sisenseContextService: SisenseContextService, themeConfig?: ThemeConfig);
    private initThemeSettings;
    private applyThemeSettings;
    /** @internal */
    getThemeSettings(): import("rxjs").Observable<CompleteThemeSettings>;
    updateThemeSettings(theme: string | ThemeSettings): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ThemeService, [null, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ThemeService>;
}
