import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, NgModule, Optional, EventEmitter, Component, ViewChild, Input, Output } from '@angular/core';
import { DataObserver, CustomThemeProvider, CustomSisenseContextProvider, CustomPluginsProvider, createClientApplication, getDashboardModel, getDashboardModels, HookAdapter, useComposedDashboardInternal, createHookApiFacade, getHierarchyModels, executeQuery, executeQueryByWidgetId, executePivotQuery, useExecuteCsvQueryInternal, getWidgetModel, getDefaultThemeSettings, getThemeSettingsByOid, ComponentAdapter, Chart, PivotTable, Table, ContextMenu, createWrapperElement, Dashboard, DashboardById, DrilldownBreadcrumbs, CriteriaFilterTile, DateRangeFilterTile, FilterTile, MemberFilterTile, RelativeDateFilterTile, ChartWidget, DrilldownWidget, createWrapperElementHandler, createComponentRenderer, PivotTableWidget, TableWidget, Widget, WidgetById, dashboardModelTranslator as dashboardModelTranslator$1, dashboardHelpers as dashboardHelpers$1, widgetModelTranslator as widgetModelTranslator$1 } from '@sisense/sdk-ui-preact';
export { boxWhiskerProcessResult } from '@sisense/sdk-ui-preact';
import { __rest, __awaiter, __decorate } from 'tslib';
import { BehaviorSubject } from 'rxjs';
import merge from 'ts-deepmerge';
import { trackProductEvent } from '@sisense/sdk-tracking';
import { getFilterListAndRelationsJaql } from '@sisense/sdk-data';
import { CommonModule } from '@angular/common';

/**
 * Creates theme context connector
 *
 * @param themeService - The theme service
 * @internal
 */
const createThemeContextConnector = (themeService) => {
    const themeSettings$ = themeService.getThemeSettings();
    const propsObserver = new DataObserver();
    themeSettings$.subscribe({
        next: (themeSettings) => {
            propsObserver.setValue({
                context: {
                    skipTracking: true,
                    themeSettings,
                },
            });
        },
        error: (error) => {
            propsObserver.setValue({
                error,
            });
        },
    });
    return {
        propsObserver,
        providerComponent: CustomThemeProvider,
    };
};
/**
 * Creates Sisense context connector
 *
 * @param sisenseContextService - The Sisense context service
 * @internal
 */
const createSisenseContextConnector = (sisenseContextService) => {
    var _a, _b;
    const { showRuntimeErrors, appConfig } = sisenseContextService.getConfig();
    const defaultSisenseContext = {
        isInitialized: true,
        tracking: {
            // if tracking is configured in appConfig, use it
            // if none is set, default to true
            enabled: (_b = (_a = appConfig === null || appConfig === void 0 ? void 0 : appConfig.trackingConfig) === null || _a === void 0 ? void 0 : _a.enabled) !== null && _b !== void 0 ? _b : true,
            packageName: 'sdk-ui-angular',
        },
        errorBoundary: {
            showErrorBox: showRuntimeErrors !== null && showRuntimeErrors !== void 0 ? showRuntimeErrors : true,
        },
    };
    const propsObserver = new DataObserver({
        context: defaultSisenseContext,
    });
    sisenseContextService
        .getApp()
        .then((app) => propsObserver.setValue({
        context: Object.assign(Object.assign({}, defaultSisenseContext), { app }),
    }))
        .catch((error) => propsObserver.setValue({
        error,
    }));
    return {
        propsObserver,
        providerComponent: CustomSisenseContextProvider,
    };
};
/**
 * Creates plugins context connector
 *
 * @param pluginsService - The plugin service
 * @internal
 */
const createPluginsContextConnector = (pluginsService) => {
    const pluginsContext = {
        pluginMap: pluginsService.getPlugins().value,
        registerPlugin: pluginsService.registerPlugin.bind(pluginsService),
        getPlugin: pluginsService.getPlugin.bind(pluginsService),
    };
    const propsObserver = new DataObserver({
        context: pluginsContext,
    });
    return {
        propsObserver,
        providerComponent: CustomPluginsProvider,
    };
};

const rootId = 'preact';
const rootContentId = 'preactContent';
const template = `
    <div #${rootId} class="csdk-full-size-container"></div>
`;
const templateWithContent = `
    <div #${rootId} class="csdk-full-size-container">
        <div #${rootContentId} class="csdk-full-size-container">
            <ng-content></ng-content>
        </div>
    </div>
`;
const styles = [
    `.csdk-full-size-container {
        width: 100%;
        height: 100%;
    }`,
];

/**
 * Token used to inject {@link SisenseContextConfig} into your application
 *
 * @example
 * Example of importing {@link SdkUiModule} and injecting {@link SisenseContextConfig} into your application:
 *
 * ```ts
 * export const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Contexts
 */
const SISENSE_CONTEXT_CONFIG_TOKEN = new InjectionToken('Props for connecting to Sisense instance');
/**
 * Service for working with Sisense Fusion context.
 *
 * @group Contexts
 */
class SisenseContextService {
    constructor(sisenseContextConfig) {
        this.appPromise = createClientApplication(sisenseContextConfig);
        const { showRuntimeErrors } = sisenseContextConfig;
        this.config = Object.assign(Object.assign({}, sisenseContextConfig), { showRuntimeErrors: showRuntimeErrors !== null && showRuntimeErrors !== void 0 ? showRuntimeErrors : true });
    }
    /** @internal */
    getApp() {
        return this.appPromise;
    }
    getConfig() {
        return this.config;
    }
}
SisenseContextService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SisenseContextService, deps: [{ token: SISENSE_CONTEXT_CONFIG_TOKEN }], target: i0.ɵɵFactoryTarget.Injectable });
SisenseContextService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SisenseContextService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SisenseContextService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Inject,
                        args: [SISENSE_CONTEXT_CONFIG_TOKEN]
                    }] }];
    } });

var packageVersion = '2.2.0';

function translateToPreactWidgetProps(widgetProps) {
    const { beforeRender, dataReady, beforeMenuOpen, dataPointClick, dataPointContextMenu, dataPointsSelect } = widgetProps, commonWidgetProps = __rest(widgetProps, ["beforeRender", "dataReady", "beforeMenuOpen", "dataPointClick", "dataPointContextMenu", "dataPointsSelect"]);
    return Object.assign(Object.assign({}, commonWidgetProps), { onBeforeRender: beforeRender, onDataReady: dataReady, onBeforeMenuOpen: beforeMenuOpen, onDataPointClick: dataPointClick
            ? (...[point, nativeEvent]) => dataPointClick({ point, nativeEvent })
            : undefined, onDataPointContextMenu: dataPointContextMenu
            ? (...[point, nativeEvent]) => dataPointContextMenu({ point, nativeEvent })
            : undefined, onDataPointsSelected: dataPointsSelect
            ? (...[points, nativeEvent]) => dataPointsSelect({ points, nativeEvent })
            : undefined });
}
function translateFromPreactWidgetProps(widgetProps) {
    const { onBeforeRender, onDataReady, onBeforeMenuOpen, onDataPointClick, onDataPointContextMenu, onDataPointsSelected } = widgetProps, commonWidgetProps = __rest(widgetProps, ["onBeforeRender", "onDataReady", "onBeforeMenuOpen", "onDataPointClick", "onDataPointContextMenu", "onDataPointsSelected"]);
    return Object.assign(Object.assign({}, commonWidgetProps), { beforeRender: onBeforeRender, dataReady: onDataReady, beforeMenuOpen: onBeforeMenuOpen, dataPointClick: onDataPointClick
            ? ({ point, nativeEvent }) => onDataPointClick(point, nativeEvent)
            : undefined, dataPointContextMenu: onDataPointContextMenu
            ? ({ point, nativeEvent }) => onDataPointContextMenu(point, nativeEvent)
            : undefined, dataPointsSelect: onDataPointsSelected
            ? ({ points, nativeEvent }) => onDataPointsSelected(points, nativeEvent)
            : undefined });
}

function translateToPreactDashboardProps(dashboardProps) {
    return Object.assign(Object.assign({}, dashboardProps), { widgets: dashboardProps.widgets.map(translateToPreactWidgetProps) });
}
function translateFromPreactDashboardProps(dashboardProps) {
    return Object.assign(Object.assign({}, dashboardProps), { widgets: dashboardProps.widgets.map(translateFromPreactWidgetProps) });
}

/**
 * Service for working with Sisense Fusion dashboards.
 *
 * **Note:** Dashboard and Widget extensions based on JS scripts and add-ons in Fusion – for example, Blox and Jump To Dashboard – are not supported.
 *
 * @group Fusion Assets
 * @fusionEmbed
 */
let DashboardService = class DashboardService {
    constructor(sisenseContextService) {
        this.sisenseContextService = sisenseContextService;
    }
    /**
     * Retrieves an existing dashboard model from the Sisense instance.
     *
     * @param dashboardOid - Identifier of the dashboard
     * @param options - Advanced configuration options
     * @returns Dashboard model
     */
    getDashboardModel(dashboardOid, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const app = yield this.sisenseContextService.getApp();
            return getDashboardModel(app.httpClient, dashboardOid, options);
        });
    }
    /**
     * Retrieves existing dashboard models from the Sisense instance.
     *
     * @param options - Advanced configuration options
     * @returns Dashboard models array
     */
    getDashboardModels(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const app = yield this.sisenseContextService.getApp();
            return getDashboardModels(app.httpClient, options);
        });
    }
    /**
     * Сomposes dashboard or separate dashboard elements into a coordinated dashboard
     * with cross filtering, and change detection.
     *
     * @example
     * An example of using the `createComposedDashboard` to construct a composed dashboard and render it:
     * ```html
      <!--Component HTML template in example.component.html-->
      <div *ngIf="dashboard$ | async as dashboard">
        <csdk-filter-tile
          *ngFor="let filter of getDashboardFilters(dashboard); trackBy: trackByIndex"
          [filter]="filter"
        />
        <csdk-widget
          *ngFor="let widget of dashboard.widgets; trackBy: trackByIndex"
          [id]="widget.id"
          [widgetType]="widget.widgetType"
          [chartType]="widget.chartType"
          [pluginType]="widget.pluginType"
          [dataSource]="widget.dataSource"
          [dataOptions]="widget.dataOptions"
          [filters]="widget.filters"
          [highlights]="widget.highlights"
          [styleOptions]="widget.styleOptions"
          [drilldownOptions]="widget.drilldownOptions"
          [title]="widget.title"
          [description]="widget.description"
          [beforeMenuOpen]="widget.beforeMenuOpen"
          (dataPointClick)="widget.dataPointClick?.($event)"
          (dataPointContextMenu)="widget.dataPointContextMenu?.($event)"
          (dataPointsSelect)="widget.dataPointsSelect?.($event)"
        />
      </div>
     * ```
     *
     * ```ts
      // Component behavior in example.component.ts
      import { Component } from '@angular/core';
      import { BehaviorSubject } from 'rxjs';
      import { DashboardService, type DashboardProps } from '@sisense/sdk-ui-angular';
  
      @Component({
        selector: 'example',
        templateUrl: './example.component.html',
        styleUrls: ['./example.component.scss'],
      })
      export class ExampleComponent {
        dashboard$: BehaviorSubject<DashboardProps> | undefined;
  
        constructor(private dashboardService: DashboardService) {}
  
        ngOnInit() {
          const initialDashboard: DashboardProps = { ... };
          const composedDashboard = this.dashboardService.createComposedDashboard(initialDashboard);
          this.dashboard$ = composedDashboard.dashboard$;
        }
  
        trackByIndex = (index: number) => index;
  
        getDashboardFilters = ({ filters }: DashboardProps) => Array.isArray(filters) ? filters : [];
      }
     * ```
     * @param initialDashboard - Initial dashboard
     * @param options - Configuration options
     * @returns Reactive composed dashboard object and API methods for interacting with it
     */
    createComposedDashboard(initialDashboard, options = {}) {
        const hookAdapter = new HookAdapter((useComposedDashboardInternal), [createSisenseContextConnector(this.sisenseContextService)]);
        const dashboard$ = new BehaviorSubject(initialDashboard);
        hookAdapter.subscribe(({ dashboard }) => {
            dashboard$.next(translateFromPreactDashboardProps(dashboard));
        });
        hookAdapter.run(translateToPreactDashboardProps(initialDashboard), options);
        const setFilters = createHookApiFacade(hookAdapter, 'setFilters', true);
        const setWidgetsLayout = createHookApiFacade(hookAdapter, 'setWidgetsLayout', true);
        return {
            dashboard$,
            setFilters,
            setWidgetsLayout,
        };
    }
};
DashboardService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DashboardService, deps: [{ token: SisenseContextService }], target: i0.ɵɵFactoryTarget.Injectable });
DashboardService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DashboardService, providedIn: 'root' });
DashboardService = __decorate([
    TrackableService(['getDashboardModel', 'getDashboardModels'])
], DashboardService);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DashboardService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }]; } });

/**
 * Service for working with Sisense Fusion hierarchies.
 *
 * @group Fusion Assets
 * @fusionEmbed
 */
let HierarchyService = class HierarchyService {
    constructor(sisenseContextService) {
        this.sisenseContextService = sisenseContextService;
    }
    /**
     * Retrieves existing hierarchy models from the Sisense instance.
     *
     * @param params - Parameters to identify the target hierarchy models
     * @returns Hierarchy models array
     */
    getHierarchyModels(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const app = yield this.sisenseContextService.getApp();
            return getHierarchyModels(app.httpClient, params, app.defaultDataSource);
        });
    }
};
HierarchyService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: HierarchyService, deps: [{ token: SisenseContextService }], target: i0.ɵɵFactoryTarget.Injectable });
HierarchyService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: HierarchyService, providedIn: 'root' });
HierarchyService = __decorate([
    TrackableService(['getHierarchyModels'])
], HierarchyService);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: HierarchyService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }]; } });

/**
 * Service for working with plugins fetched from an external environment.
 *
 * Provides methods for registering, retrieving, and interacting with plugins.
 *
 * @internal
 * @group Contexts
 */
class PluginsService {
    constructor() {
        this.pluginMap$ = new BehaviorSubject(new Map());
    }
    /**
     * Registers a new plugin into the plugin map.
     *
     * @param pluginType - The unique identifier for the plugin type.
     * @param plugin - The plugin instance to register.
     */
    registerPlugin(pluginType, plugin) {
        const pluginMap = this.pluginMap$.value;
        if (!pluginMap.has(pluginType)) {
            pluginMap.set(pluginType, plugin);
            this.pluginMap$.next(pluginMap);
        }
    }
    /**
     * Retrieves a plugin by its type.
     *
     * @param pluginType - The unique identifier for the plugin type.
     * @returns The plugin instance if found, otherwise undefined.
     */
    getPlugin(pluginType) {
        return this.pluginMap$.value.get(pluginType);
    }
    /**
     * Retrieves a complete plugin map.
     *
     * @returns A plugin map.
     */
    getPlugins() {
        return this.pluginMap$;
    }
}
PluginsService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PluginsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
PluginsService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PluginsService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PluginsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return []; } });

/**
 * Service for executing data queries.
 *
 * @group Queries
 */
let QueryService = class QueryService {
    constructor(sisenseContextService) {
        this.sisenseContextService = sisenseContextService;
    }
    /**
     * Executes a data query. If you want to display the query results, you can use
     * them to populate Compose SDK UI elements or third party UI elements.
     *
     * To learn how to populate third party UI elements with query results, see the
     * [External Charts Guide](/guides/sdk/guides/charts/guide-external-charts.html#query)
     *
     * @param params - Query parameters
     * @return Query result
     */
    executeQuery(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const { dataSource, dimensions, measures, filters, highlights, count, offset, ungroup, beforeQuery, } = params;
            const app = yield this.sisenseContextService.getApp();
            const { filters: filterList, relations: filterRelations } = getFilterListAndRelationsJaql(filters);
            const data = yield executeQuery({
                dataSource,
                dimensions,
                measures,
                filters: filterList,
                filterRelations,
                highlights,
                count,
                offset,
                ungroup,
            }, app, { onBeforeQuery: beforeQuery });
            return { data };
        });
    }
    /**
     * Executes a data query extracted from an existing widget in the Sisense instance.
     *
     * @param params - Parameters to identify the target widget
     * @returns Query result
     */
    executeQueryByWidgetId(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const app = yield this.sisenseContextService.getApp();
            return executeQueryByWidgetId(Object.assign(Object.assign({}, params), { app, onBeforeQuery: params.beforeQuery }));
        });
    }
    /**
     * Executes a data query for a pivot table.
     *
     * @param params - Pivot query parameters
     * @return Pivot query result
     * @beta
     */
    executePivotQuery(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const { dataSource, rows, columns, values, grandTotals, filters, highlights, count, offset, beforeQuery, } = params;
            const { filters: filterList, relations: filterRelations } = getFilterListAndRelationsJaql(filters);
            const app = yield this.sisenseContextService.getApp();
            const data = yield executePivotQuery({
                dataSource,
                rows,
                columns,
                values,
                grandTotals,
                filters: filterList,
                filterRelations,
                highlights,
                count,
                offset,
            }, app, { onBeforeQuery: beforeQuery });
            return { data };
        });
    }
    /**
     * Executes a CSV data query.
     * Similar to {@link QueryService.executeQuery}, but returns the data in CSV format as text or as a stream.
     *
     * @param params - CSV query parameters
     * @return CSV query result
     */
    executeCsvQuery(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const hookAdapter = new HookAdapter(useExecuteCsvQueryInternal, [
                createSisenseContextConnector(this.sisenseContextService),
            ]);
            const resultPromise = new Promise((resolve, reject) => {
                hookAdapter.subscribe((res) => {
                    const { data, isSuccess, isError, error } = res;
                    if (isSuccess) {
                        resolve({ data });
                    }
                    else if (isError) {
                        reject(error);
                    }
                });
            });
            hookAdapter.run(params);
            return resultPromise.finally(() => {
                hookAdapter.destroy();
            });
        });
    }
};
QueryService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: QueryService, deps: [{ token: SisenseContextService }], target: i0.ɵɵFactoryTarget.Injectable });
QueryService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: QueryService, providedIn: 'root' });
QueryService = __decorate([
    TrackableService(['executeQuery', 'executeQueryByWidgetId', 'executePivotQuery'])
], QueryService);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: QueryService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }]; } });

/**
 * Service for working with Sisense Fusion widgets.
 *
 * @group Fusion Assets
 * @fusionEmbed
 */
let WidgetService = class WidgetService {
    constructor(sisenseContextService) {
        this.sisenseContextService = sisenseContextService;
    }
    /**
     * Retrieves an existing widget model from the Sisense instance.
     *
     * @param params - Parameters to identify the target widget
     * @returns Widget model
     */
    getWidgetModel(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const { dashboardOid, widgetOid } = params;
            const app = yield this.sisenseContextService.getApp();
            return getWidgetModel(app.httpClient, dashboardOid, widgetOid);
        });
    }
};
WidgetService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WidgetService, deps: [{ token: SisenseContextService }], target: i0.ɵɵFactoryTarget.Injectable });
WidgetService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WidgetService, providedIn: 'root' });
WidgetService = __decorate([
    TrackableService(['getWidgetModel'])
], WidgetService);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WidgetService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }]; } });

class DecoratorsModule {
    constructor(sisenseContextService) {
        DecoratorsModule.sisenseContextService = sisenseContextService;
    }
}
DecoratorsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DecoratorsModule, deps: [{ token: SisenseContextService }], target: i0.ɵɵFactoryTarget.NgModule });
DecoratorsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: DecoratorsModule });
DecoratorsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DecoratorsModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DecoratorsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    exports: [],
                }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }]; } });

function Trackable(target, propertyKey, descriptor) {
    const originalMethod = descriptor.value;
    descriptor.value = function (...args) {
        track('sdkAngularServiceMethodExecuted', propertyKey);
        return originalMethod.apply(this, args);
    };
    return descriptor;
}
/** @internal */
function TrackableService(trackableMethods) {
    return function (ServiceClass) {
        trackableMethods.forEach((methodName) => {
            // eslint-disable-next-line security/detect-object-injection
            const original = ServiceClass.prototype[methodName];
            // eslint-disable-next-line security/detect-object-injection
            ServiceClass.prototype[methodName] = function (...params) {
                track('sdkAngularServiceMethodExecuted', `${ServiceClass.name}.${methodName}`);
                return original.apply(this, params);
            };
        });
    };
}
function track(action, methodName) {
    var _a, _b, _c;
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const app = yield DecoratorsModule.sisenseContextService.getApp();
            const trackingEnabled = (_c = (_b = (_a = app.settings) === null || _a === void 0 ? void 0 : _a.trackingConfig) === null || _b === void 0 ? void 0 : _b.enabled) !== null && _c !== void 0 ? _c : true;
            if (app === null || app === void 0 ? void 0 : app.httpClient) {
                const payload = {
                    packageName: 'sdk-ui-angular',
                    packageVersion,
                    methodName,
                };
                void trackProductEvent(action, payload, app.httpClient, !trackingEnabled);
            }
        }
        catch (e) {
            console.warn('tracking error', e);
        }
    });
}

/**
 * Token used to inject {@link ThemeConfig} into your application
 *
 * @example
 *
 * Example of injecting both {@link SisenseContextConfig} and {@link ThemeConfig} into your application:
 *
 * ```ts
 * export const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *     {
 *       provide: THEME_CONFIG_TOKEN,
 *       useValue: {
 *         // initial theme settings
 *       } as ThemeConfig,
 *     },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Contexts
 */
const THEME_CONFIG_TOKEN = new InjectionToken('theme configuration');
/**
 * Service for working with Sisense Fusion themes.
 *
 * If no theme service is used, the current Fusion theme is applied by default.
 *
 * @group Contexts
 */
let ThemeService = class ThemeService {
    constructor(sisenseContextService, themeConfig) {
        this.sisenseContextService = sisenseContextService;
        this.themeSettings$ = new BehaviorSubject(getDefaultThemeSettings());
        void this.initThemeSettings(themeConfig === null || themeConfig === void 0 ? void 0 : themeConfig.theme);
    }
    initThemeSettings(theme) {
        return __awaiter(this, void 0, void 0, function* () {
            const app = yield this.sisenseContextService.getApp();
            // apply system theme settings first
            yield this.applyThemeSettings(app.settings.serverThemeSettings);
            if (theme) {
                yield this.updateThemeSettings(theme);
            }
        });
    }
    applyThemeSettings(theme) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const app = yield this.sisenseContextService.getApp();
                const isThemeOid = typeof theme === 'string';
                let userThemeSettings = theme;
                if (isThemeOid) {
                    userThemeSettings = yield getThemeSettingsByOid(theme, app.httpClient);
                }
                const mergedThemeSettings = merge.withOptions({ mergeArrays: false }, this.themeSettings$.value, userThemeSettings);
                this.themeSettings$.next(mergedThemeSettings);
            }
            catch (error) {
                this.themeSettings$.error(error);
            }
        });
    }
    /** @internal */
    getThemeSettings() {
        return this.themeSettings$.asObservable();
    }
    updateThemeSettings(theme) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.applyThemeSettings(theme);
        });
    }
};
ThemeService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ThemeService, deps: [{ token: SisenseContextService }, { token: THEME_CONFIG_TOKEN, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
ThemeService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ThemeService, providedIn: 'root' });
ThemeService = __decorate([
    TrackableService(['updateThemeSettings'])
], ThemeService);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ThemeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () {
        return [{ type: SisenseContextService }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [THEME_CONFIG_TOKEN]
                    }] }];
    } });

/**
 * An Angular component used for easily switching chart types or rendering multiple series of different chart types.
 *
 * @example
 * An example of using the `Chart` component to
 * plot a column chart of the Sample Healthcare data source hosted in a Sisense instance:
 *
 * ```html
 * <!--Component HTML template in .component.html-->
 * <csdk-chart
 *   [chartType]="chart.chartType"
 *   [dataSet]="chart.dataSet"
 *   [dataOptions]="chart.dataOptions"
 *   [filters]="chart.filters"
 *   [styleOptions]="chart.styleOptions"
 * />
 * ```
 *
 * ```ts
 * // Component behavior in .component.ts
 * chart = {
 *   chartType: 'column' as ChartType,
 *   dataSet: DM.DataSource,
 *   dataOptions: {
 *     category: [DM.Admissions.Admission_Time.Months],
 *     value: [measureFactory.count(DM.Admissions.Patient_ID, 'Total Patients')],
 *     breakBy: [],
 *   },
 *   filters: [filterFactory.members(DM.Doctors.Specialty, ['Oncology', 'Cardiology'])],
 *   styleOptions: {
 *     width: 800,
 *     height: 500,
 *     xAxis: {
 *       title: {
 *         text: 'Months',
 *         enabled: true,
 *       },
 *     },
 *     yAxis: {
 *       title: {
 *         text: 'Total Patients',
 *         enabled: true,
 *       },
 *     },
 *   },
 * };
 * ```
 *
 * <img src="media://angular-chart-example.png" width="800px" />
 * @shortDescription Common component for rendering charts of different types including table
 * @group Charts
 */
class ChartComponent {
    /**
     * Constructor for the `Chart` component.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(Chart, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        var _a, _b;
        return {
            chartType: this.chartType,
            dataSet: this.dataSet,
            dataOptions: this.dataOptions,
            filters: this.filters,
            highlights: this.highlights,
            styleOptions: this.styleOptions,
            onBeforeRender: (_a = this.beforeRender) === null || _a === void 0 ? void 0 : _a.bind(this),
            onDataReady: (_b = this.dataReady) === null || _b === void 0 ? void 0 : _b.bind(this),
            onDataPointClick: (...[point, nativeEvent]) => this.dataPointClick.emit({ point, nativeEvent }),
            onDataPointContextMenu: (...[point, nativeEvent]) => this.dataPointContextMenu.emit({ point, nativeEvent }),
            onDataPointsSelected: (...[points, nativeEvent]) => this.dataPointsSelect.emit({ points, nativeEvent }),
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
ChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ChartComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
ChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ChartComponent, selector: "csdk-chart", inputs: { chartType: "chartType", dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ChartComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-chart', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], chartType: [{
                type: Input
            }], dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * A component similar to a {@link LineChartComponent},
 * but with filled in areas under each line and an option to display them as stacked.
 *
 * @example
 * ```html
 *    <csdk-area-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-area-chart-example.png" width="800px" />
 * @group Charts
 */
class AreaChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!AreaChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!AreaChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!AreaChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'area';
    }
}
AreaChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AreaChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
AreaChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: AreaChartComponent, selector: "csdk-area-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AreaChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-area-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * A component that displays a range of data over a given time period or across multiple categories.
 * It is particularly useful for visualizing the minimum and maximum values in a dataset, along with
 * the area between these values.
 *
 * @example
 * ```html
 *    <csdk-area-range-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType, RangeChartDataOptions } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'arearange' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Admissions.Admission_Time.Years],
      value: [
        {
            title: 'Admission Cost Range',
            upperBound: measureFactory.multiply(
              measureFactory.sum(DM.Admissions.Cost_of_admission, 'Lower Admission'),
              0.6,
            ),
            lowerBound: measureFactory.multiply(
              measureFactory.sum(DM.Admissions.Cost_of_admission, 'Upper Admission'),
              1.4,
             ),
        }
      ],
      breakBy: [],
    } as RangeChartDataOptions,
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-area-range-chart-example.png" width="800px" />
 * @group Charts
 */
class AreaRangeChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'arearange';
    }
}
AreaRangeChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AreaRangeChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
AreaRangeChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: AreaRangeChartComponent, selector: "csdk-area-range-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AreaRangeChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-area-range-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * An Angular component that allows to visualize geographical data as polygons on a map.
 *
 * @example
 * ```html
 *    <csdk-areamap-chart
 *      [dataSet]="areamapChart.dataSet"
 *      [dataOptions]="areamapChart.dataOptions"
 *      [styleOptions]="areamapChart.styleOptions"
 *      (dataPointClick)="logArguments($event)"
 *    />
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import { measureFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-ecommerce';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  areamapChart = {
    dataSet: DM.DataSource,
    dataOptions: {
      geo: [DM.Country.Country],
      color: [measureFactory.sum(DM.Commerce.Revenue, 'Color by Revenue')],
    } as AreamapChartDataOptions,
    styleOptions: {
      mapType: 'world',
    } as AreamapStyleOptions,
  };

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-areamap-chart-example.png" width="800px" />
 * @group Charts
 */
class AreamapChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!AreamapChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /** @internal */
        this.chartType = 'areamap';
    }
}
AreamapChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AreamapChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
AreamapChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: AreamapChartComponent, selector: "csdk-areamap-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AreamapChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-areamap-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }] } });

/**
 * A component representing categorical data with horizontal rectangular bars,
 * whose lengths are proportional to the values that they represent.
 *
 * @example
 * ```html
 *    <csdk-bar-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-bar-chart-example.png" width="800px" />
 * @group Charts
 */
class BarChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!BarChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!BarChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!BarChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'bar';
    }
}
BarChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: BarChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
BarChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: BarChartComponent, selector: "csdk-bar-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: BarChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-bar-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * An Angular component representing data in a way that visually describes the distribution
 * variability, and center of a data set along an axis.
 *
 * @example
 * ```html
 *    <csdk-boxplot-chart
 *      [dataSet]="boxplotChart.dataSet"
 *      [dataOptions]="boxplotChart.dataOptions"
 *      [highlights]="boxplotChart.highlights"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import { filterFactory } from '@sisense/sdk-data';
import type { BoxplotChartDataOptions } from '@sisense/sdk-ui-angular';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  boxplotChart = {
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [DM.Admissions.TimeofStay],
      boxType: 'iqr',
      outliersEnabled: true,
    } as BoxplotChartDataOptions,
    highlights: [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])],
  };

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-boxplot-chart-example.png" width="800px" />
 * @group Charts
 */
class BoxplotChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'boxplot';
    }
}
BoxplotChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: BoxplotChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
BoxplotChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: BoxplotChartComponent, selector: "csdk-boxplot-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: BoxplotChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-boxplot-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * A component representing categorical data with vertical rectangular bars
 * whose heights are proportional to the values that they represent.
 *
 * @example
 * ```html
 *    <csdk-column-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-column-chart-example.png" width="800px" />
 * @group Charts
 */
class ColumnChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'column';
    }
}
ColumnChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ColumnChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ColumnChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ColumnChartComponent, selector: "csdk-column-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ColumnChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-column-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * A component representing data progressively decreasing in size or quantity through a funnel shape.
 *
 * @example
 * ```html
 *    <csdk-funnel-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';
@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-funnel-chart-example.png" width="800px" />
 * @group Charts
 */
class FunnelChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'funnel';
    }
}
FunnelChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FunnelChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FunnelChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: FunnelChartComponent, selector: "csdk-funnel-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FunnelChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-funnel-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * A component that provides various options for displaying one or two numeric values as a number, gauge or ticker.
 *
 * @example
 * ```html
 *    <csdk-indicator-chart
 *      [dataSet]="indicator.dataSet"
 *      [dataOptions]="indicator.dataOptions"
 *      [filters]="filters"
 *      [styleOptions]="indicator.styleOptions"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { IndicatorStyleOptions } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  indicator = {
    dataSet: DM.DataSource,
    dataOptions: {
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      secondary: [measureFactory.sum(DM.Admissions.Diagnosis_ID)],
    },
    styleOptions: {
      indicatorComponents: {
        title: {
          shouldBeShown: true,
          text: 'Total Cost_of_admission',
        },
        secondaryTitle: {
          text: 'Total Diagnosis_ID',
        },
        ticks: {
          shouldBeShown: true,
        },
        labels: {
          shouldBeShown: true,
        },
      },
      subtype: 'indicator/gauge',
      skin: 2,
    } as IndicatorStyleOptions,
  };

}
 * ```
 * <img src="media://angular-indicator-chart-example.png" width="800px" />
 * @group Charts
 */
class IndicatorChartComponent {
    constructor() {
        /** @internal */
        this.chartType = 'indicator';
    }
}
IndicatorChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: IndicatorChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
IndicatorChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: IndicatorChartComponent, selector: "csdk-indicator-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: IndicatorChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-indicator-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }] } });

/**
 * A component displaying data as a series of points connected by a line. Used to show trends or changes over time.
 *
 * @example
 * ```html
 *    <csdk-line-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';
@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-line-chart-example.png" width="800px" />
 * @group Charts
 */
class LineChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!LineChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!LineChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!LineChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'line';
    }
}
LineChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LineChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
LineChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: LineChartComponent, selector: "csdk-line-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LineChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-line-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * A component representing data in a circular graph with the data shown as slices of a whole,
 * with each slice representing a proportion of the total.
 *
 * @example
 * ```html
 *    <csdk-pie-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-pie-chart-example.png" width="800px" />
 * @group Charts
 */
class PieChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!PieChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!PieChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!PieChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'pie';
    }
}
PieChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PieChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
PieChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: PieChartComponent, selector: "csdk-pie-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PieChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-pie-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * Pivot Table with and pagination.
 *
 * @example
 * ```html
 *  <csdk-pivot-table
 *    [dataSet]="pivotTable.dataSet"
 *    [dataOptions]="pivotTable.dataOptions"
 *    [filters]="pivotTable.filters"
 *    [styleOptions]="pivotTable.styleOptions"
 *  />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-ecommerce';
import type { PivotTableDataOptions } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {

  pivotTableDataOptions: PivotTableDataOptions = {
    rows: [
      { column: DM.Category.Category, includeSubTotals: true },
      { column: DM.Commerce.AgeRange, includeSubTotals: true },
      DM.Commerce.Condition,
    ],
    columns: [{ column: DM.Commerce.Gender, includeSubTotals: true }],
    values: [
      measureFactory.sum(DM.Commerce.Cost, 'Total Cost'),
      {
        column: measureFactory.sum(DM.Commerce.Revenue, 'Total Revenue'),
        totalsCalculation: 'sum',
        dataBars: true,
      },
    ],
    grandTotals: { title: 'Grand Total', rows: true, columns: true },
  };

  pivotTable = {
    dataSet: DM.DataSource,
    dataOptions: this.pivotTableDataOptions,
    filters: [filterFactory.members(DM.Commerce.Gender, ['Female', 'Male'])],
    styleOptions: { width: 1400, height: 600, rowsPerPage: 50 },
  };

}
 * ```
 * <img src="media://angular-pivot-table-example.png" width="800px" />
 * @group Data Grids
 * @beta
 */
class PivotTableComponent {
    constructor(sisenseContextService, themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.componentAdapter = new ComponentAdapter(PivotTable, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /** @internal */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /** @internal */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            dataSet: this.dataSet,
            dataOptions: this.dataOptions,
            filters: this.filters,
            highlights: this.highlights,
            styleOptions: this.styleOptions,
        };
    }
    /** @internal */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
PivotTableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PivotTableComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
PivotTableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: PivotTableComponent, selector: "csdk-pivot-table", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PivotTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-pivot-table', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }] } });

/**
 * A component comparing multiple categories/variables with a spacial perspective in a radial chart.
 *
 * @example
 * ```html
 *    <csdk-polar-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-polar-chart-example.png" width="800px" />
 * @group Charts
 */
class PolarChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!PolarChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!PolarChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!PolarChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'polar';
    }
}
PolarChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PolarChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
PolarChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: PolarChartComponent, selector: "csdk-polar-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PolarChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-polar-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * A component displaying the distribution of two variables on an X-Axis, Y-Axis,
 * and two additional fields of data that are shown as colored circles scattered across the chart.
 *
 * **Point**: A field that for each of its members a scatter point is drawn. The maximum amount of data points is 500.
 *
 * **Size**: An optional field represented by the size of the circles.
 * If omitted, all scatter points are equal in size. If used, the circle sizes are relative to their values.
 *
 * @example
 * ```html
 *    <csdk-scatter-chart
 *      [dataSet]="scatter.dataSet"
 *      [dataOptions]="scatter.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  scatter = {
    dataSet: DM.DataSource,
    dataOptions: {
      x: DM.Admissions.Room_ID,
      y: measureFactory.sum(DM.Admissions.Cost_of_admission),
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-scatter-chart-example.png" width="800px" />
 * @group Charts
 */
class ScatterChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!ScatterChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ScatterChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ScatterChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'scatter';
    }
}
ScatterChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ScatterChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ScatterChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ScatterChartComponent, selector: "csdk-scatter-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ScatterChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-scatter-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * An Angular component that allows to visualize geographical data as data points on a map.
 *
 * @example
 * ```html
 *    <csdk-scattermap-chart
 *      [dataSet]="scattermapChart.dataSet"
 *      [dataOptions]="scattermapChart.dataOptions"
 *      [styleOptions]="scattermapChart.styleOptions"
 *      (dataPointClick)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import type { ScattermapStyleOptions,ScattermapChartDataOptions } from '@sisense/sdk-ui-angular';
import * as DM from '../../assets/sample-ecommerce';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  scattermapChart = {
    dataSet: DM.DataSource,
    dataOptions: {
      geo: [DM.Country.Country],
      size: measureFactory.sum(DM.Commerce.Cost, 'Size by Cost'),
      colorBy: {
        column: measureFactory.sum(DM.Commerce.Revenue, 'Color by Revenue'),
        color: 'green',
      },
      details: DM.Category.Category,
    } as ScattermapChartDataOptions,
    styleOptions: {
      markers: {
        fill: 'hollow-bold',
      },
    } as ScattermapStyleOptions,
  };

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-scattermap-chart-example.png" width="800px" />
 * @group Charts
 */
class ScattermapChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!ScattermapChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /** @internal */
        this.chartType = 'scattermap';
    }
}
ScattermapChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ScattermapChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ScattermapChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ScattermapChartComponent, selector: "csdk-scattermap-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ScattermapChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-scattermap-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }] } });

/**
 * A component displaying hierarchical data in the form of nested slices.
 * This type of chart can be used instead of a pie chart for comparing a large number of categories and sub-categories.
 *
 * @example
 * ```html
 *    <csdk-sunburst-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-sunburst-chart-example.png" width="800px" />
 * @group Charts
 */
class SunburstChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'sunburst';
    }
}
SunburstChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SunburstChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
SunburstChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: SunburstChartComponent, selector: "csdk-sunburst-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SunburstChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-sunburst-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * Table with aggregation and pagination.
 *
 * @example
 * ```html
 *  <csdk-table [dataSet]="table.dataSet" [dataOptions]="table.dataOptions" [filters]="filters" />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  table = {
    dataSet: DM.DataSource,
    dataOptions: {
      columns: [DM.Admissions.Patient_ID, measureFactory.sum(DM.Admissions.Cost_of_admission)],
    },
  };

}
 * ```
 * <img src="media://angular-table-chart-example.png" width="800px" />
 * @group Data Grids
 */
class TableComponent {
    constructor(sisenseContextService, themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.componentAdapter = new ComponentAdapter(Table, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /** @internal */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /** @internal */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            dataSet: this.dataSet,
            dataOptions: this.dataOptions,
            filters: this.filters,
            styleOptions: this.styleOptions,
            onDataReady: this.dataReady,
        };
    }
    /** @internal */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
TableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
TableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TableComponent, selector: "csdk-table", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", styleOptions: "styleOptions", dataReady: "dataReady" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-table', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], dataReady: [{
                type: Input
            }] } });

/**
 * A component displaying hierarchical data in the form of nested rectangles.
 * This type of chart can be used instead of a column chart for comparing a large number of categories and sub-categories.
 *
 * @example
 * ```html
 *    <csdk-treemap-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import type { ChartType } from '@sisense/sdk-ui-angular';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-treemap-chart-example.png" width="800px" />
 * @group Charts
 */
class TreemapChartComponent {
    constructor() {
        /**
         * {@inheritDoc @sisense/sdk-ui!TreemapChartProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!TreemapChartProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!TreemapChartProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        /** @internal */
        this.chartType = 'treemap';
    }
}
TreemapChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TreemapChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
TreemapChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TreemapChartComponent, selector: "csdk-treemap-chart", inputs: { dataSet: "dataSet", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, ngImport: i0, template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `, isInline: true, dependencies: [{ kind: "component", type: ChartComponent, selector: "csdk-chart", inputs: ["chartType", "dataSet", "dataOptions", "filters", "highlights", "styleOptions", "beforeRender", "dataReady"], outputs: ["dataPointClick", "dataPointContextMenu", "dataPointsSelect"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TreemapChartComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'csdk-treemap-chart',
                    template: `
    <csdk-chart
      [chartType]="chartType"
      [dataSet]="dataSet"
      [dataOptions]="dataOptions"
      [filters]="filters"
      [highlights]="highlights"
      [styleOptions]="styleOptions"
      [beforeRender]="beforeRender"
      [dataReady]="dataReady"
      (dataPointClick)="dataPointClick.emit($any($event))"
      (dataPointContextMenu)="dataPointContextMenu.emit($any($event))"
      (dataPointsSelect)="dataPointsSelect.emit($any($event))"
    />
  `,
                }]
        }], propDecorators: { dataSet: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * Context Menu Component
 *
 * @group Drilldown
 */
class ContextMenuComponent {
    /**
     * Constructor for the `ContextMenuComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!ContextMenuProps.closeContextMenu}
         */
        this.contextMenuClose = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(ContextMenu, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            position: this.position,
            itemSections: this.itemSections,
            closeContextMenu: () => this.contextMenuClose.emit(),
            children: createWrapperElement(this.preactContentRef.nativeElement),
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
ContextMenuComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ContextMenuComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
ContextMenuComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ContextMenuComponent, selector: "csdk-context-menu", inputs: { position: "position", itemSections: "itemSections" }, outputs: { contextMenuClose: "contextMenuClose" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }, { propertyName: "preactContentRef", first: true, predicate: ["preactContent"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\">\n        <div #preactContent class=\"csdk-full-size-container\">\n            <ng-content></ng-content>\n        </div>\n    </div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ContextMenuComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-context-menu', template: templateWithContent, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], preactContentRef: [{
                type: ViewChild,
                args: [rootContentId]
            }], position: [{
                type: Input
            }], itemSections: [{
                type: Input
            }], contextMenuClose: [{
                type: Output
            }] } });

/**
 * An Angular component used for easily rendering a dashboard created in Sisense Fusion.
 *
 * **Note:** Dashboard and Widget extensions based on JS scripts and add-ons in Fusion – for example, Blox and Jump To Dashboard – are not supported.
 *
 * @example
 * ```html
 * <csdk-dashboard
 *  *ngIf="dashboard"
 *  [title]="dashboard.title"
 *  [layoutOptions]="dashboard.layoutOptions"
 *  [widgets]="dashboard.widgets"
 *  [filters]="dashboard.filters"
 *  [defaultDataSource]="dashboard.defaultDataSource"
 *  [widgetsOptions]="dashboard.widgetsOptions"
 * />
 * ```
 *
 * ```ts
 * import { Component } from '@angular/core';
 * import {
 *   type DashboardProps,
 *   DashboardService,
 *   dashboardModelTranslator,
 * } from '@sisense/sdk-ui-angular';
 *
 * @Component({
 *  selector: 'app-dashboard',
 *  templateUrl: './dashboard.component.html',
 *  styleUrls: ['./dashboard.component.scss'],
 * })
 * export class DashboardComponent {
 *
 *  dashboard: DashboardProps | null = null;
 *
 *  constructor(private dashboardService: DashboardService) {}
 *
 *  async ngOnInit(): Promise<void> {
 *    const dashboardModel = await this.dashboardService.getDashboardModel('your-dashboard-oid', { includeWidgets: true, includeFilters: true });
 *    this.dashboard = dashboardModelTranslator.toDashboardProps(dashboardModel);
 *  }
 * ```
 *
 * To learn more about this and related dashboard components,
 * see [Embedded Dashboards](/guides/sdk/guides/dashboards/index.html).
 * @group Dashboards
 */
class DashboardComponent {
    /**
     * Constructor for the `Dashboard` component.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService, 
    /**
     * Plugin service
     *
     * @internal
     * @category Constructor
     */
    pluginService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.pluginService = pluginService;
        this.componentAdapter = new ComponentAdapter(Dashboard, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
            createPluginsContextConnector(this.pluginService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return translateToPreactDashboardProps({
            title: this.title,
            layoutOptions: this.layoutOptions,
            config: this.config,
            widgets: this.widgets,
            filters: this.filters,
            defaultDataSource: this.defaultDataSource,
            widgetsOptions: this.widgetsOptions,
            styleOptions: this.styleOptions,
            tabbersOptions: this.tabbersOptions,
        });
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
DashboardComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DashboardComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }, { token: PluginsService }], target: i0.ɵɵFactoryTarget.Component });
DashboardComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: DashboardComponent, selector: "csdk-dashboard", inputs: { title: "title", layoutOptions: "layoutOptions", config: "config", widgets: "widgets", filters: "filters", defaultDataSource: "defaultDataSource", widgetsOptions: "widgetsOptions", styleOptions: "styleOptions", tabbersOptions: "tabbersOptions" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DashboardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-dashboard', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }, { type: PluginsService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], title: [{
                type: Input
            }], layoutOptions: [{
                type: Input
            }], config: [{
                type: Input
            }], widgets: [{
                type: Input
            }], filters: [{
                type: Input
            }], defaultDataSource: [{
                type: Input
            }], widgetsOptions: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], tabbersOptions: [{
                type: Input
            }] } });

/**
 * An Angular component used for easily rendering a dashboard by its ID created in a Sisense Fusion instance.
 *
 * **Note:** Dashboard and Widget extensions based on JS scripts and add-ons in Fusion – for example, Blox and Jump To Dashboard – are not supported.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * @Component({
 *   selector: 'code-example',
 *   template: `
 *     <div style="width: 100vw;">
 *       <csdk-dashboard-by-id *ngIf="dashboardOid" [dashboardOid]="dashboardOid" />
 *     </div>
 *   `,
 *  })
 * export class CodeExampleComponent {
 *   dashboardOid = 'your-dashboard-oid';
 * }
 * ```
 *
 * To learn more about this and related dashboard components,
 * see [Embedded Dashboards](/guides/sdk/guides/dashboards/index.html).
 * @group Fusion Assets
 * @fusionEmbed
 */
class DashboardByIdComponent {
    /**
     * Constructor for the `DashboardById` component.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService, 
    /**
     * Plugin service
     *
     * @internal
     * @category Constructor
     */
    pluginService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.pluginService = pluginService;
        this.componentAdapter = new ComponentAdapter(DashboardById, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
            createPluginsContextConnector(this.pluginService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            dashboardOid: this.dashboardOid,
            config: this.config,
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
DashboardByIdComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DashboardByIdComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }, { token: PluginsService }], target: i0.ɵɵFactoryTarget.Component });
DashboardByIdComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: DashboardByIdComponent, selector: "csdk-dashboard-by-id", inputs: { dashboardOid: "dashboardOid", config: "config" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DashboardByIdComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-dashboard-by-id', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }, { type: PluginsService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], dashboardOid: [{
                type: Input
            }], config: [{
                type: Input
            }] } });

/**
 * Drilldown Breadcrumbs Component
 *
 * @group Drilldown
 */
class DrilldownBreadcrumbsComponent {
    /**
     * Constructor for the `DrilldownBreadcrumbsComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!DrilldownBreadcrumbsProps.clearDrilldownSelections}
         *
         * @category Widget
         */
        this.drilldownSelectionsClear = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!DrilldownBreadcrumbsProps.sliceDrilldownSelections}
         *
         * @category Widget
         */
        this.drilldownSelectionsSlice = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(DrilldownBreadcrumbs, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            filtersDisplayValues: this.filtersDisplayValues,
            currentDimension: this.currentDimension,
            clearDrilldownSelections: () => this.drilldownSelectionsClear.emit(),
            sliceDrilldownSelections: (i) => this.drilldownSelectionsSlice.emit(i),
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
DrilldownBreadcrumbsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DrilldownBreadcrumbsComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
DrilldownBreadcrumbsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: DrilldownBreadcrumbsComponent, selector: "csdk-drilldown-breadcrumbs", inputs: { filtersDisplayValues: "filtersDisplayValues", currentDimension: "currentDimension" }, outputs: { drilldownSelectionsClear: "drilldownSelectionsClear", drilldownSelectionsSlice: "drilldownSelectionsSlice" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DrilldownBreadcrumbsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-drilldown-breadcrumbs', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], filtersDisplayValues: [{
                type: Input
            }], currentDimension: [{
                type: Input
            }], drilldownSelectionsClear: [{
                type: Output
            }], drilldownSelectionsSlice: [{
                type: Output
            }] } });

/**
 * Criteria Filter Tile Component
 *
 * @example
 * ```html
 *     <csdk-criteria-filter-tile
 *       [title]="criteriaFilterTileProps.title"
 *       [filter]="criteriaFilterTileProps.filter"
 *       (filterChange)="criteriaFilterTileProps.setFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;
 *   title: 'Room Number',
 *   filter: filterFactory.lessThan(DM.Rooms.Room_number, 200) ,
 *   setFilter({ filter }: { filter: Filter | null }) {
 *     console.log(filter);
 *     if (filter) {
 *       this.filter = filter ;
 *     }
 *   },
 * }
 * ```
 * <img src="media://angular-criteria-filter-tile-example.png" width="400px" />
 * @group Filter Tiles
 */
class CriteriaFilterTileComponent {
    /**
     * Constructor for the `CriteriaFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!CriteriaFilterTileProps.onUpdate}
         */
        this.filterChange = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(CriteriaFilterTile, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            title: this.title,
            filter: this.filter,
            arrangement: this.arrangement,
            measures: this.measures,
            tileDesignOptions: this.tileDesignOptions,
            onUpdate: (...[filter]) => this.filterChange.emit({ filter }),
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
CriteriaFilterTileComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CriteriaFilterTileComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
CriteriaFilterTileComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: CriteriaFilterTileComponent, selector: "csdk-criteria-filter-tile", inputs: { title: "title", filter: "filter", arrangement: "arrangement", measures: "measures", tileDesignOptions: "tileDesignOptions" }, outputs: { filterChange: "filterChange" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CriteriaFilterTileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-criteria-filter-tile', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], title: [{
                type: Input
            }], filter: [{
                type: Input
            }], arrangement: [{
                type: Input
            }], measures: [{
                type: Input
            }], tileDesignOptions: [{
                type: Input
            }], filterChange: [{
                type: Output
            }] } });

/**
 * Date Range Filter Tile Component
 *
 * @example
 * ```html
 * <csdk-date-range-filter-tile
 *       [title]="dateRangeFilterTileProps.title"
 *       [attribute]="dateRangeFilterTileProps.attribute"
 *       [filter]="dateRangeFilterTileProps.filter"
 *       (filterChange)="dateRangeFilterTileProps.setFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;

 *   dateRangeFilterTileProps = {
 *     title: 'Range Filter',
 *     attribute: DM.ER.Date.Years,
 *     filter: filterFactory.dateRange(DM.ER.Date.Years),
 *     setFilter({ filter }: { filter: Filter | null }) {
 *       console.log(filter);
 *       if (filter) {
 *         this.filter = filter;
 *       }
 *     },
 *   };
 * }
 * ```
 * <img src="media://angular-date-range-filter-tile-example.png" width="600px" />
 * @group Filter Tiles
 */
class DateRangeFilterTileComponent {
    /**
     * Constructor for the `DateRangeFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.onChange}
         */
        this.filterChange = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(DateRangeFilterTile, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            title: this.title,
            attribute: this.attribute,
            dataSource: this.dataSource,
            filter: this.filter,
            earliestDate: this.earliestDate,
            lastDate: this.lastDate,
            onChange: (...[filter]) => this.filterChange.emit({ filter }),
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
DateRangeFilterTileComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DateRangeFilterTileComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
DateRangeFilterTileComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: DateRangeFilterTileComponent, selector: "csdk-date-range-filter-tile", inputs: { title: "title", attribute: "attribute", dataSource: "dataSource", filter: "filter", earliestDate: "earliestDate", lastDate: "lastDate" }, outputs: { filterChange: "filterChange" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DateRangeFilterTileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-date-range-filter-tile', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], title: [{
                type: Input
            }], attribute: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], filter: [{
                type: Input
            }], earliestDate: [{
                type: Input
            }], lastDate: [{
                type: Input
            }], filterChange: [{
                type: Output
            }] } });

/**
 * An extended version of Angular's `EventEmitter` that tracks
 * whether any listeners (subscribers) are attached.
 *
 * Useful when you need to know if an `@Output()` is being observed
 * in the template (i.e., bound with `(event)="..."`).
 *
 * @template T - The type of values emitted by the EventEmitter.
 */
class EventEmitterWithHasListeners extends EventEmitter {
    constructor() {
        super(...arguments);
        /**
         * Indicates whether the EventEmitter has at least one active subscriber.
         */
        this.hasListeners = false;
    }
    /**
     * Overrides the default `subscribe()` method to set `hasListeners` to true
     * when a new subscriber is added.
     *
     * @param args - The arguments passed to the `subscribe()` method.
     * @returns A subscription object used to unsubscribe from the event.
     */
    subscribe(...args) {
        this.hasListeners = true;
        return super.subscribe(...args);
    }
}

/**
 * UI component that renders a filter tile based on filter type
 *
 * @example
 * Here’s how to render a filter model as a filter tile.
 *
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-filter-tile
  [filter]="filterTileProps.filter"
  (filterChange)="filterTileProps.filterChange($event)"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';
import { type FilterTileProps } from '@sisense/sdk-ui-angular';
import { filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  filterTileProps: FilterTileProps = {
    filter: filterFactory.members(DM.ER.Date.Years, ['2013-01-01T00:00:00']),
    filterChange({ filter }) {
      if (filter) {
        this.filter = filter;
      }
    },
  };
}
 * ```
 * <img src="media://angular-member-filter-tile-example.png" width="225px" />
 * @group Filter Tiles
 * @shortDescription Facade component rendering a filter tile based on filter type
 */
class FilterTileComponent {
    /**
     * Constructor for the `FilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc FilterTileProps.filterChange}
         */
        this.filterChange = new EventEmitter();
        /**
         * {@inheritDoc FilterTileProps.filterEdit}
         */
        this.filterEdit = new EventEmitterWithHasListeners();
        /**
         * {@inheritDoc FilterTileProps.filterDelete}
         */
        this.filterDelete = new EventEmitterWithHasListeners();
        this.componentAdapter = new ComponentAdapter(FilterTile, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        const hasFilterEditListeners = this.filterEdit
            .hasListeners;
        const hasFilterDeleteListeners = this.filterDelete
            .hasListeners;
        return Object.assign(Object.assign({ filter: this.filter, defaultDataSource: this.defaultDataSource, onChange: (...[filter]) => this.filterChange.emit({ filter }) }, (hasFilterEditListeners && {
            onEdit: (...[levelIndex]) => this.filterEdit.emit({ levelIndex }),
        })), (hasFilterDeleteListeners && { onDelete: () => this.filterDelete.emit() }));
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
FilterTileComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FilterTileComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
FilterTileComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: FilterTileComponent, selector: "csdk-filter-tile", inputs: { filter: "filter", defaultDataSource: "defaultDataSource" }, outputs: { filterChange: "filterChange", filterEdit: "filterEdit", filterDelete: "filterDelete" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FilterTileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-filter-tile', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], filter: [{
                type: Input
            }], defaultDataSource: [{
                type: Input
            }], filterChange: [{
                type: Output
            }], filterEdit: [{
                type: Output
            }], filterDelete: [{
                type: Output
            }] } });

/**
 * Member Filter Tile Component
 *
 * @example
 * ```html
 *     <csdk-member-filter-tile
 *       title="Years Filter"
 *       [attribute]="DM.ER.Date.Years"
 *       [filter]="memberFilterTileProps.yearFilter"
 *       (filterChange)="memberFilterTileProps.setYearFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;
 *   memberFilterTileProps = {
 *     yearFilter: filterFactory.members(DM.ER.Date.Years, ['2013-01-01T00:00:00']),
 *     setYearFilter({ filter }: { filter: Filter | null }) {
 *       if (filter) {
 *         this.yearFilter = filter;
 *       }
 *     },
 *   };
 * }
 * ```
 * <img src="media://angular-member-filter-tile-example.png" width="225px" />
 * @group Filter Tiles
 */
class MemberFilterTileComponent {
    /**
     * Constructor for the `MemberFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!MemberFilterTileProps.onChange}
         */
        this.filterChange = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(MemberFilterTile, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            title: this.title,
            dataSource: this.dataSource,
            attribute: this.attribute,
            filter: this.filter,
            onChange: (...[filter]) => this.filterChange.emit({ filter }),
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
MemberFilterTileComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MemberFilterTileComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
MemberFilterTileComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MemberFilterTileComponent, selector: "csdk-member-filter-tile", inputs: { title: "title", dataSource: "dataSource", attribute: "attribute", filter: "filter" }, outputs: { filterChange: "filterChange" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MemberFilterTileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-member-filter-tile', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], title: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], attribute: [{
                type: Input
            }], filter: [{
                type: Input
            }], filterChange: [{
                type: Output
            }] } });

/**
 * Relative Date Filter Tile Component
 *
 * @example
 * ```html
 * <csdk-relative-date-filter-tile
 *       [title]="relativeDateFilterTileProps.title"
 *       [arrangement]="relativeDateFilterTileProps.arrangement"
 *       [filter]="relativeDateFilterTileProps.filter"
 *       (filterChange)="relativeDateFilterTileProps.setFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;
 *
 *   relativeDateFilterTileProps = {
 *     title: 'Relative Date Filter',
 *     arrangement: 'vertical',
 *     filter: filterFactory.dateRelativeTo(DM.ER.Date.Days, 0, 150),
 *     setFilter({ filter }: { filter: Filter | null }) {
 *       console.log(filter);
 *       if (filter) {
 *         this.filter = filter;
 *       }
 *     },
 *   };
 * }
 * ```
 * <img src="media://angular-relative-date-filter-tile-example.png" width="600px" />
 * @group Filter Tiles
 */
class RelativeDateFilterTileComponent {
    /**
     * Constructor for the `RelativeDateFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!RelativeDateFilterTileProps.onUpdate}
         */
        this.filterChange = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(RelativeDateFilterTile, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            title: this.title,
            filter: this.filter,
            arrangement: this.arrangement,
            limit: this.limit,
            onUpdate: (...[filter]) => this.filterChange.emit({ filter }),
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
RelativeDateFilterTileComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: RelativeDateFilterTileComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
RelativeDateFilterTileComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: RelativeDateFilterTileComponent, selector: "csdk-relative-date-filter-tile", inputs: { title: "title", filter: "filter", arrangement: "arrangement", limit: "limit" }, outputs: { filterChange: "filterChange" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: RelativeDateFilterTileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-relative-date-filter-tile', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], title: [{
                type: Input
            }], filter: [{
                type: Input
            }], arrangement: [{
                type: Input
            }], limit: [{
                type: Input
            }], filterChange: [{
                type: Output
            }] } });

/**
 * The Chart Widget component extending {@link ChartComponent} to support widget style options.
 *
 * @example
 * ```html
 * <csdk-chart-widget
 *   [chartType]="chartWidget.chartType"
 *   [dataSource]="chartWidget.dataSource"
 *   [dataOptions]="chartWidget.dataOptions"
 *   [highlights]="filters"
 *   [title]="chartWidget.title"
 *   [description]="chartWidget.description"
 *   [beforeRender]="onBeforeRender"
 *   (dataPointClick)="logArguments($event)"
 *   (dataPointContextMenu)="logArguments($event)"
 *   (dataPointsSelect)="logArguments($event)"
 * />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { ChartType } from '@sisense/sdk-ui-angular';
 * import { filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-widgets',
 *   templateUrl: './widgets.component.html',
 *   styleUrls: ['./widgets.component.scss'],
 * })
 * export class WidgetsComponent {
 *   filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
 *   chartWidget = {
 *     chartType: 'column' as ChartType,
 *     dataSource: DM.DataSource,
 *     dataOptions: {
 *       category: [DM.Divisions.Divison_name],
 *       value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
 *       breakBy: [],
 *     },
 *     title: 'Chart Title',
 *     description: 'Chart Description',
 *   };
 *  logArguments(...args: any[]) {
 *   console.log(args);
 * }
 *
 * onBeforeRender(options: any) {
 *   console.log('beforeRender');
 *   console.log(options);
 *   return options;
 * }
 *
 * }
 * ```
 * <img src="media://angular-chart-widget-example.png" width="500px" />
 * @group Dashboards
 */
class ChartWidgetComponent {
    constructor(sisenseContextService, themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(ChartWidget, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /** @internal */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /** @internal */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        var _a, _b;
        return {
            chartType: this.chartType,
            dataSource: this.dataSource,
            dataOptions: this.dataOptions,
            filters: this.filters,
            highlights: this.highlights,
            styleOptions: this.styleOptions,
            drilldownOptions: this.drilldownOptions,
            title: this.title,
            description: this.description,
            highlightSelectionDisabled: this.highlightSelectionDisabled,
            onBeforeRender: (_a = this.beforeRender) === null || _a === void 0 ? void 0 : _a.bind(this),
            onDataReady: (_b = this.dataReady) === null || _b === void 0 ? void 0 : _b.bind(this),
            onDataPointClick: (...[point, nativeEvent]) => this.dataPointClick.emit({ point, nativeEvent }),
            onDataPointContextMenu: (...[point, nativeEvent]) => this.dataPointContextMenu.emit({ point, nativeEvent }),
            onDataPointsSelected: (...[points, nativeEvent]) => this.dataPointsSelect.emit({ points, nativeEvent }),
        };
    }
    /** @internal */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
ChartWidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ChartWidgetComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
ChartWidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ChartWidgetComponent, selector: "csdk-chart-widget", inputs: { chartType: "chartType", dataSource: "dataSource", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", drilldownOptions: "drilldownOptions", title: "title", description: "description", highlightSelectionDisabled: "highlightSelectionDisabled", beforeRender: "beforeRender", dataReady: "dataReady" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ChartWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-chart-widget', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], chartType: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], drilldownOptions: [{
                type: Input
            }], title: [{
                type: Input
            }], description: [{
                type: Input
            }], highlightSelectionDisabled: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * An Angular component designed to add drilldown functionality to any type of chart.
 *
 * It acts as a wrapper around a given chart component, enhancing it with drilldown capabilities
 *
 * The widget offers several features including:
 * - A context menu for initiating drilldown actions (can be provided as a custom component)
 * - Breadcrumbs that not only allow for drilldown selection slicing but also
 * provide an option to clear the selection (can be provided as a custom component)
 * - Filters specifically created for drilldown operation
 * - An option to navigate to the next drilldown dimension
 *
 * When an `initialDimension` is specified, the `drilldownDimension` will automatically inherit its value,
 * even before any points on the chart are selected.
 * This allows for complete control over the chart's dimensions to be handed over to the DrilldownWidget
 *
 * @example
 * An example of using the `csdk-drilldown-widget` component to plot a `csdk-column-chart`
 * over the Sample Healthcare data source hosted in a Sisense instance:
 * ```ts
 * // Component behavior in .component.ts
 * chart = {
 *   dataOptions: {
 *     category: [DM.Divisions.Divison_name],
 *     value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
 *     breakBy: [],
 *   },
 *   dataPointContextMenu: ({ point, nativeEvent }: { point: any; nativeEvent: MouseEvent }) => {
 *     this.drilldownResult?.onDataPointsSelected?.([point], nativeEvent);
 *     this.drilldownResult?.onContextMenu({
 *       left: nativeEvent.clientX,
 *       top: nativeEvent.clientY,
 *     });
 *   }
 * }
 *
 * drilldownResult?: CustomDrilldownResult;
 *
 * drilldown = {
 *   drilldownPaths: [DM.Patients.Gender, DM.Admissions.Surgical_Procedure],
 *   initialDimension: DM.Divisions.Divison_name,
 *   drilldownChange: (drilldownResult: CustomDrilldownResult) => {
 *     this.drilldownResult = drilldownResult;
 *     this.chart.dataOptions = {
 *       ...this.chart.dataOptions,
 *       category: [drilldownResult.drilldownDimension]
 *     }
 *   }
 * };
 * ```
 * ```html
 * <!--Component HTML template in .component.html-->
 * <csdk-drilldown-widget
 *   [drilldownPaths]="drilldown.drilldownPaths"
 *   [initialDimension]="drilldown.initialDimension"
 *   (drilldownResultChange)="drilldown.drilldownChange($event)"
 * >
 *   <csdk-column-chart
 *     [dataSet]="DM.DataSource"
 *     [dataOptions]="chart.dataOptions"
 *     [filters]="drilldownResult?.drilldownFilters || []"
 *     (dataPointContextMenu)="chart.dataPointContextMenu($event)"
 *   />
 * </csdk-drilldown-widget>
 * ```
 * <img src="media://angular-drilldown-widget-example.png" width="800px" />
 * @group Drilldown
 */
class DrilldownWidgetComponent {
    /**
     * Constructor for the `DrilldownWidgetComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * Drilldown result change handler callback
         *
         * @category Callbacks
         */
        this.drilldownResultChange = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(DrilldownWidget, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        var _a, _b;
        return {
            drilldownPaths: this.drilldownPaths,
            initialDimension: this.initialDimension,
            config: Object.assign(Object.assign(Object.assign({}, this.config), (((_a = this.config) === null || _a === void 0 ? void 0 : _a.breadcrumbsComponent) && {
                breadcrumbsComponent: createWrapperElementHandler(this.config.breadcrumbsComponent),
            })), (((_b = this.config) === null || _b === void 0 ? void 0 : _b.contextMenuComponent) && {
                contextMenuComponent: (contextMenuProps) => createWrapperElement(this.config.contextMenuComponent(contextMenuProps)),
            })),
            children: (customDrilldownResult) => {
                const { breadcrumbsComponent } = customDrilldownResult;
                this.drilldownResultChange.emit(Object.assign(Object.assign({}, customDrilldownResult), (breadcrumbsComponent && {
                    breadcrumbsComponent: { render: createComponentRenderer(breadcrumbsComponent) },
                })));
                return createWrapperElement(this.preactContentRef.nativeElement);
            },
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
DrilldownWidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DrilldownWidgetComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
DrilldownWidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: DrilldownWidgetComponent, selector: "csdk-drilldown-widget", inputs: { drilldownPaths: "drilldownPaths", initialDimension: "initialDimension", config: "config" }, outputs: { drilldownResultChange: "drilldownResultChange" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }, { propertyName: "preactContentRef", first: true, predicate: ["preactContent"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\">\n        <div #preactContent class=\"csdk-full-size-container\">\n            <ng-content></ng-content>\n        </div>\n    </div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: DrilldownWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-drilldown-widget', template: templateWithContent, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], preactContentRef: [{
                type: ViewChild,
                args: [rootContentId]
            }], drilldownPaths: [{
                type: Input
            }], initialDimension: [{
                type: Input
            }], config: [{
                type: Input
            }], drilldownResultChange: [{
                type: Output
            }] } });

/**
 * The Pivot Table Widget component extends the {@link PivotTableComponent} component to support widget features,
 * including a header, widget style options, and more.
 *
 * @example
 * ```html
<csdk-pivot-table-widget
  [dataSource]="pivotProps.dataSource"
  [dataOptions]="pivotProps.dataOptions"
  [filters]="pivotProps.filters"
  [styleOptions]="pivotProps.styleOptions"
  [title]="pivotProps.title"
  [description]="pivotProps.description"
/>
 * ```
 * ```ts
import { Component } from '@angular/core';
import { type PivotTableWidgetProps } from '@sisense/sdk-ui-angular';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-ecommerce';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {

  pivotProps: PivotTableWidgetProps = {
    dataSource: DM.DataSource,
    dataOptions: {
      rows: [
        { column: DM.Category.Category, includeSubTotals: true },
        { column: DM.Commerce.AgeRange, includeSubTotals: true },
        DM.Commerce.Condition,
      ],
      columns: [{ column: DM.Commerce.Gender, includeSubTotals: true }],
      values: [
        measureFactory.sum(DM.Commerce.Cost, 'Total Cost'),
        {
          column: measureFactory.sum(DM.Commerce.Revenue, 'Total Revenue'),
          totalsCalculation: 'sum',
          dataBars: true,
        },
      ],
      grandTotals: { title: 'Grand Total', rows: true, columns: true },
    },
    filters: [filterFactory.members(DM.Commerce.Gender, ['Female', 'Male'])],
    styleOptions: { width: 1400, height: 600, rowsPerPage: 25 },
    title: 'Pivot Table Widget',
    description: 'Pivot Table Widget Description',
  };
}
 * ```
 * <img src="media://angular-pivot-table-widget-example.png" width="800px" />
 * @group Dashboards
 * @beta
 */
class PivotTableWidgetComponent {
    constructor(sisenseContextService, themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.componentAdapter = new ComponentAdapter(PivotTableWidget, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /** @internal */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /** @internal */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            dataSource: this.dataSource,
            dataOptions: this.dataOptions,
            filters: this.filters,
            highlights: this.highlights,
            styleOptions: this.styleOptions,
            title: this.title,
            description: this.description,
        };
    }
    /** @internal */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
PivotTableWidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PivotTableWidgetComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
PivotTableWidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: PivotTableWidgetComponent, selector: "csdk-pivot-table-widget", inputs: { dataSource: "dataSource", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", title: "title", description: "description" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PivotTableWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-pivot-table-widget', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], dataSource: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], title: [{
                type: Input
            }], description: [{
                type: Input
            }] } });

/**
 * The Table Widget component extending {@link TableComponent} component to support widget style options.
 *
 * @example
 * ```html
 *  <csdk-table-widget
 *    [dataSource]="table.dataSet"
 *    [dataOptions]="table.dataOptions"
 *    [filters]="filters"
 *    [title]="table.title"
 *    [description]="table.description"
 *  />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { ChartType } from '@sisense/sdk-ui-angular';
 * import { filterFactory, measureFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *  selector: 'app-widgets',
 * templateUrl: './widgets.component.html',
 * styleUrls: ['./widgets.component.scss'],
 * })
 * export class WidgetsComponent {
 * filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
 *
 * table = {
 *    dataSet: DM.DataSource,
 *    dataOptions: {
 *      columns: [DM.Admissions.Patient_ID, measureFactory.sum(DM.Admissions.Cost_of_admission)],
 *    }
 *    title: 'Widget Title',
 *    description: 'Widget Description',
 *  };
 * }
 * ```
 * <img src="media://angular-table-widget-example.png" width="800px" />
 * @internal
 */
class TableWidgetComponent {
    constructor(sisenseContextService, themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.componentAdapter = new ComponentAdapter(TableWidget, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            dataSource: this.dataSource,
            dataOptions: this.dataOptions,
            filters: this.filters,
            styleOptions: this.styleOptions,
            title: this.title,
            description: this.description,
        };
    }
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
TableWidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableWidgetComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
TableWidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TableWidgetComponent, selector: "csdk-table-widget", inputs: { dataSource: "dataSource", dataOptions: "dataOptions", filters: "filters", styleOptions: "styleOptions", title: "title", description: "description" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-table-widget', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], dataSource: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], title: [{
                type: Input
            }], description: [{
                type: Input
            }] } });

/**
 * Facade component that renders a widget within a dashboard based on the widget type.
 *
 * @example
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-widget
  [id]="widgetProps.id"
  [title]="widgetProps.title"
  [widgetType]="widgetProps.widgetType"
  [chartType]="widgetProps.chartType"
  [dataSource]="widgetProps.dataSource"
  [dataOptions]="widgetProps.dataOptions"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';
import { type WidgetProps } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  widgetProps: WidgetProps = {
    id: 'widget-id',
    widgetType: 'chart',
    chartType: 'column',
    title: 'Widget Title',
    dataSource: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };
}
 * ```
 * <img src="media://angular-chart-widget-example.png" width="500px" />
 * @group Dashboards
 */
class WidgetComponent {
    constructor(sisenseContextService, themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointClick}
         *
         * @category Callbacks
         */
        this.dataPointClick = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointContextMenu}
         *
         * @category Callbacks
         */
        this.dataPointContextMenu = new EventEmitter();
        /**
         * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointsSelected}
         *
         * @category Callbacks
         */
        this.dataPointsSelect = new EventEmitter();
        this.componentAdapter = new ComponentAdapter(Widget, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /** @internal */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /** @internal */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        var _a, _b, _c;
        return translateToPreactWidgetProps({
            id: this.id,
            widgetType: this.widgetType,
            chartType: this.chartType,
            pluginType: this.pluginType,
            dataSource: this.dataSource,
            dataOptions: this.dataOptions,
            filters: this.filters,
            highlights: this.highlights,
            styleOptions: this.styleOptions,
            drilldownOptions: this.drilldownOptions,
            title: this.title,
            description: this.description,
            highlightSelectionDisabled: this.highlightSelectionDisabled,
            beforeRender: (_a = this.beforeRender) === null || _a === void 0 ? void 0 : _a.bind(this),
            dataReady: (_b = this.dataReady) === null || _b === void 0 ? void 0 : _b.bind(this),
            beforeMenuOpen: (_c = this.beforeMenuOpen) === null || _c === void 0 ? void 0 : _c.bind(this),
            dataPointClick: this.dataPointClick.emit.bind(this.dataPointClick),
            dataPointContextMenu: this.dataPointContextMenu.emit.bind(this.dataPointContextMenu),
            dataPointsSelect: this.dataPointsSelect.emit.bind(this.dataPointsSelect),
        });
    }
    /** @internal */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
WidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WidgetComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
WidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: WidgetComponent, selector: "csdk-widget", inputs: { id: "id", widgetType: "widgetType", chartType: "chartType", pluginType: "pluginType", dataSource: "dataSource", dataOptions: "dataOptions", filters: "filters", highlights: "highlights", styleOptions: "styleOptions", drilldownOptions: "drilldownOptions", title: "title", description: "description", highlightSelectionDisabled: "highlightSelectionDisabled", beforeRender: "beforeRender", dataReady: "dataReady", beforeMenuOpen: "beforeMenuOpen" }, outputs: { dataPointClick: "dataPointClick", dataPointContextMenu: "dataPointContextMenu", dataPointsSelect: "dataPointsSelect" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-widget', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], id: [{
                type: Input
            }], widgetType: [{
                type: Input
            }], chartType: [{
                type: Input
            }], pluginType: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], dataOptions: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], drilldownOptions: [{
                type: Input
            }], title: [{
                type: Input
            }], description: [{
                type: Input
            }], highlightSelectionDisabled: [{
                type: Input
            }], beforeRender: [{
                type: Input
            }], dataReady: [{
                type: Input
            }], beforeMenuOpen: [{
                type: Input
            }], dataPointClick: [{
                type: Output
            }], dataPointContextMenu: [{
                type: Output
            }], dataPointsSelect: [{
                type: Output
            }] } });

/**
 * The `WidgetById` component, which is a thin wrapper on {@link ChartWidgetComponent},
 * is used to render a widget created in a Sisense Fusion instance.
 *
 * To learn more about using Sisense Fusion Widgets in Compose SDK, see
 * [Sisense Fusion Widgets](https://sisense.dev/guides/sdk/guides/charts/guide-fusion-widgets.html).
 *
 * @example
 * ```html
 * <csdk-widget-by-id
 *    [widgetOid]="widgetOid"
 *    [dashboardOid]="dashboardOid"
 *    [includeDashboardFilters]="true"
 * />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 *
 * @Component({
 *  selector: 'app-widgets',
 *  templateUrl: './widgets.component.html',
 *  styleUrls: ['./widgets.component.scss'],
 * })
 * export class WidgetsComponent {
 *  widgetOid: string = '60f3e3e3e4b0e3e3e4b0e3e3';
 *  dashboardOid: string = '60f3e3e3e4b0e3e3e4b0e3e3';
 * }
 * ```
 * @group Fusion Assets
 * @fusionEmbed
 */
class WidgetByIdComponent {
    constructor(sisenseContextService, themeService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.componentAdapter = new ComponentAdapter(WidgetById, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
        ]);
    }
    /** @internal */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /** @internal */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    /** @internal */
    getPreactComponentProps() {
        var _a;
        return {
            widgetOid: this.widgetOid,
            dashboardOid: this.dashboardOid,
            filters: this.filters,
            highlights: this.highlights,
            filtersMergeStrategy: this.filtersMergeStrategy,
            includeDashboardFilters: this.includeDashboardFilters,
            title: this.title,
            description: this.description,
            styleOptions: this.styleOptions,
            highlightSelectionDisabled: this.highlightSelectionDisabled,
            drilldownOptions: this.drilldownOptions,
            onDataReady: (_a = this.dataReady) === null || _a === void 0 ? void 0 : _a.bind(this),
        };
    }
    /** @internal */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
WidgetByIdComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WidgetByIdComponent, deps: [{ token: SisenseContextService }, { token: ThemeService }], target: i0.ɵɵFactoryTarget.Component });
WidgetByIdComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: WidgetByIdComponent, selector: "csdk-widget-by-id", inputs: { widgetOid: "widgetOid", dashboardOid: "dashboardOid", filters: "filters", highlights: "highlights", filtersMergeStrategy: "filtersMergeStrategy", includeDashboardFilters: "includeDashboardFilters", title: "title", description: "description", styleOptions: "styleOptions", highlightSelectionDisabled: "highlightSelectionDisabled", drilldownOptions: "drilldownOptions", dataReady: "dataReady" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WidgetByIdComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-widget-by-id', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: SisenseContextService }, { type: ThemeService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], widgetOid: [{
                type: Input
            }], dashboardOid: [{
                type: Input
            }], filters: [{
                type: Input
            }], highlights: [{
                type: Input
            }], filtersMergeStrategy: [{
                type: Input
            }], includeDashboardFilters: [{
                type: Input
            }], title: [{
                type: Input
            }], description: [{
                type: Input
            }], styleOptions: [{
                type: Input
            }], highlightSelectionDisabled: [{
                type: Input
            }], drilldownOptions: [{
                type: Input
            }], dataReady: [{
                type: Input
            }] } });

/**
 * SDK UI Module, which is a container for components.
 *
 * @example
 * Example of importing `SdkUiModule` and injecting {@link SisenseContextConfig} into your application:
 *
 * ```ts
 * export const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Contexts
 */
class SdkUiModule {
}
SdkUiModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SdkUiModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SdkUiModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: SdkUiModule, declarations: [ChartComponent,
        TableComponent,
        ChartWidgetComponent,
        ColumnChartComponent,
        BarChartComponent,
        AreaChartComponent,
        AreaRangeChartComponent,
        LineChartComponent,
        IndicatorChartComponent,
        ScatterChartComponent,
        PieChartComponent,
        FunnelChartComponent,
        PolarChartComponent,
        TreemapChartComponent,
        SunburstChartComponent,
        TableWidgetComponent,
        WidgetByIdComponent,
        MemberFilterTileComponent,
        DrilldownWidgetComponent,
        DateRangeFilterTileComponent,
        RelativeDateFilterTileComponent,
        CriteriaFilterTileComponent,
        DrilldownBreadcrumbsComponent,
        ContextMenuComponent,
        BoxplotChartComponent,
        ScattermapChartComponent,
        AreamapChartComponent,
        PivotTableComponent,
        DashboardByIdComponent,
        DashboardComponent,
        PivotTableWidgetComponent,
        FilterTileComponent,
        WidgetComponent], imports: [CommonModule, DecoratorsModule], exports: [ChartComponent,
        TableComponent,
        ChartWidgetComponent,
        ColumnChartComponent,
        BarChartComponent,
        AreaChartComponent,
        AreaRangeChartComponent,
        LineChartComponent,
        IndicatorChartComponent,
        ScatterChartComponent,
        PieChartComponent,
        FunnelChartComponent,
        PolarChartComponent,
        TreemapChartComponent,
        SunburstChartComponent,
        TableWidgetComponent,
        WidgetByIdComponent,
        MemberFilterTileComponent,
        DrilldownWidgetComponent,
        DateRangeFilterTileComponent,
        RelativeDateFilterTileComponent,
        CriteriaFilterTileComponent,
        DrilldownBreadcrumbsComponent,
        ContextMenuComponent,
        BoxplotChartComponent,
        ScattermapChartComponent,
        AreamapChartComponent,
        PivotTableComponent,
        DashboardByIdComponent,
        DashboardComponent,
        PivotTableWidgetComponent,
        FilterTileComponent,
        WidgetComponent] });
SdkUiModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SdkUiModule, imports: [CommonModule, DecoratorsModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SdkUiModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ChartComponent,
                        TableComponent,
                        ChartWidgetComponent,
                        ColumnChartComponent,
                        BarChartComponent,
                        AreaChartComponent,
                        AreaRangeChartComponent,
                        LineChartComponent,
                        IndicatorChartComponent,
                        ScatterChartComponent,
                        PieChartComponent,
                        FunnelChartComponent,
                        PolarChartComponent,
                        TreemapChartComponent,
                        SunburstChartComponent,
                        TableWidgetComponent,
                        WidgetByIdComponent,
                        MemberFilterTileComponent,
                        DrilldownWidgetComponent,
                        DateRangeFilterTileComponent,
                        RelativeDateFilterTileComponent,
                        CriteriaFilterTileComponent,
                        DrilldownBreadcrumbsComponent,
                        ContextMenuComponent,
                        BoxplotChartComponent,
                        ScattermapChartComponent,
                        AreamapChartComponent,
                        PivotTableComponent,
                        DashboardByIdComponent,
                        DashboardComponent,
                        PivotTableWidgetComponent,
                        FilterTileComponent,
                        WidgetComponent,
                    ],
                    imports: [CommonModule, DecoratorsModule],
                    exports: [
                        ChartComponent,
                        TableComponent,
                        ChartWidgetComponent,
                        ColumnChartComponent,
                        BarChartComponent,
                        AreaChartComponent,
                        AreaRangeChartComponent,
                        LineChartComponent,
                        IndicatorChartComponent,
                        ScatterChartComponent,
                        PieChartComponent,
                        FunnelChartComponent,
                        PolarChartComponent,
                        TreemapChartComponent,
                        SunburstChartComponent,
                        TableWidgetComponent,
                        WidgetByIdComponent,
                        MemberFilterTileComponent,
                        DrilldownWidgetComponent,
                        DateRangeFilterTileComponent,
                        RelativeDateFilterTileComponent,
                        CriteriaFilterTileComponent,
                        DrilldownBreadcrumbsComponent,
                        ContextMenuComponent,
                        BoxplotChartComponent,
                        ScattermapChartComponent,
                        AreamapChartComponent,
                        PivotTableComponent,
                        DashboardByIdComponent,
                        DashboardComponent,
                        PivotTableWidgetComponent,
                        FilterTileComponent,
                        WidgetComponent,
                    ],
                    providers: [],
                }]
        }] });

// This file re-exports common types/utils from @sisense/sdk-ui-preact
// Re-exports utils from @sisense/sdk-ui-preact

/**
 * Translates {@link DashboardModel} to {@link DashboardProps}.
 *
 * @example
 * ```html
<csdk-dashboard
  *ngIf="dashboard"
  [title]="dashboard.title"
  [layoutOptions]="dashboard.layoutOptions"
  [widgets]="dashboard.widgets"
  [filters]="dashboard.filters"
  [defaultDataSource]="dashboard.defaultDataSource"
  [widgetsOptions]="dashboard.widgetsOptions"
/>
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import {
  type DashboardProps,
  DashboardService,
  dashboardModelTranslator,
} from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-dashboard',
  templateUrl: './dashboard.component.html',
  styleUrls: ['./dashboard.component.scss'],
})
export class DashboardComponent {
  dashboard: DashboardProps | null = null;

  constructor(private dashboardService: DashboardService) {}

  async ngOnInit(): Promise<void> {
    const dashboardModel = await this.dashboardService.getDashboardModel('your-dashboard-oid', {
      includeWidgets: true,
      includeFilters: true,
    });
    this.dashboard = dashboardModelTranslator.toDashboardProps(dashboardModel);
  }
}
 * ```
 */
function toDashboardProps(dashboardModel) {
    return dashboardModelTranslator$1.toDashboardProps(dashboardModel);
}

var dashboardModelTranslator = /*#__PURE__*/Object.freeze({
    __proto__: null,
    toDashboardProps: toDashboardProps
});

/**
 * {@inheritDoc @sisense/sdk-ui!dashboardHelpers.replaceFilters}
 *
 * @example
 * Replace all filters on a dashboard with a new set of filters.
 * ```ts
 * const existingDashboard: DashboardProps = {...}
 * const newFilters: Filter[] = [{...}, {...}, ...];
 * const updatedDashboard = dashboardHelpers.replaceFilters(existingDashboard, newFilters);
 * ```
 * @param dashboard - The original dashboard (`DashboardProps`) whose filters are to be replaced.
 * @param newFilters - An array of new filters or filter relations to set on the dashboard.
 * @returns A new dashboard instance with the updated filters.
 */
const replaceFilters = (dashboard, newFilters) => {
    return dashboardHelpers$1.replaceFilters(dashboard, newFilters);
};
/**
 * {@inheritDoc @sisense/sdk-ui!dashboardHelpers.addFilter}
 *
 * @example
 * Add a new filter to a dashboard.
 * ```ts
 * const existingDashboard: DashboardProps = {...};
 * const newFilter: Filter = {...};
 * const updatedDashboard = dashboardHelpers.addFilter(existingDashboard, newFilter);
 * ```
 * @param dashboard - The original dashboard (`DashboardProps`) to which the filter will be added.
 * @param newFilter - The filter to add to the dashboard.
 * @returns A new dashboard instance with the new filter added.
 */
const addFilter = (dashboard, newFilter) => {
    return dashboardHelpers$1.addFilter(dashboard, newFilter);
};
/**
 * {@inheritDoc @sisense/sdk-ui!dashboardHelpers.addFilters}
 *
 * @example
 * Add multiple new filters to a dashboard.
 * ```ts
 * const existingDashboard: DashboardProps = {...};
 * const newFilters: Filter[] = [{...}, {...}, ...];
 * const updatedDashboard = dashboardHelpers.addFilters(existingDashboard, newFilters);
 * ```
 * @param dashboard - The original dashboard (`DashboardProps`) to which the filters will be added.
 * @param newFilters - An array of filters to add to the dashboard.
 * @returns A new dashboard instance with the new filters added.
 */
const addFilters = (dashboard, newFilters) => {
    return dashboardHelpers$1.addFilters(dashboard, newFilters);
};
/**
 * {@inheritDoc @sisense/sdk-ui!dashboardHelpers.replaceFilter}
 *
 * @example
 * Replace a filter in a dashboard.
 * ```ts
 * const existingDashboard: DashboardProps = {...};
 * const filterToReplace: Filter = {...};
 * const newFilter: Filter = {...};
 * const updatedDashboard = dashboardHelpers.replaceFilter(existingDashboard, filterToReplace, newFilter);
 * ```
 * @param dashboard - The original dashboard (`DashboardProps`) containing the filter to be replaced.
 * @param filterToReplace - The existing filter to be replaced.
 * @param newFilter - The new filter to replace the existing one.
 * @returns A new dashboard instance with the specified filter replaced.
 */
const replaceFilter = (dashboard, filterToReplace, newFilter) => {
    return dashboardHelpers$1.replaceFilter(dashboard, filterToReplace, newFilter);
};
/**
 * {@inheritDoc @sisense/sdk-ui!dashboardHelpers.removeFilter}
 *
 * @example
 * Remove a filter from a dashboard.
 * ```ts
 * const existingDashboard: DashboardProps = {...};
 * const filterToRemove: Filter = {...};
 * const updatedDashboard = dashboardHelpers.removeFilter(existingDashboard, filterToRemove);
 * ```
 * @param dashboard - The original dashboard (`DashboardProps`) from which to remove the filter.
 * @param filterToRemove - The filter to be removed.
 * @returns A new dashboard instance with the specified filter removed.
 */
const removeFilter = (dashboard, filterToRemove) => {
    return dashboardHelpers$1.removeFilter(dashboard, filterToRemove);
};
/**
 * {@inheritDoc @sisense/sdk-ui!dashboardHelpers.removeFilters}
 *
 * @example
 * Remove multiple filters from a dashboard.
 * ```ts
 * const existingDashboard: DashboardProps = {...};
 * const filtersToRemove: Filter[] = [{...}, {...}, ...];
 * const updatedDashboard = dashboardHelpers.removeFilters(existingDashboard, filtersToRemove);
 * ```
 * @param dashboard - The original dashboard (`DashboardProps`) from which the specified filters are removed.
 * @param filtersToRemove - An array of filters to remove.
 * @returns A new dashboard instance with the specified filters removed.
 */
const removeFilters = (dashboard, filtersToRemove) => {
    return dashboardHelpers$1.removeFilters(dashboard, filtersToRemove);
};

var dashboardHelpers = /*#__PURE__*/Object.freeze({
    __proto__: null,
    addFilter: addFilter,
    addFilters: addFilters,
    removeFilter: removeFilter,
    removeFilters: removeFilters,
    replaceFilter: replaceFilter,
    replaceFilters: replaceFilters
});

/**
 * Translates a {@link WidgetModel} to the parameters for executing a query for the widget.
 *
 * @example
 * ```ts
const widgetModel = await widgetService.getWidgetModel({
  dashboardOid: 'your-dashboard-oid',
  widgetOid: 'your-widget-oid'
});
const executeQueryParams = widgetModelTranslator.toExecuteQueryParams(widgetModel);
const queryResult = await queryService.executeQuery(executeQueryParams);
 * ```
 *
 * Note: this method is not supported for getting pivot query.
 * Use {@link toExecutePivotQueryParams} instead for getting query parameters for the pivot widget.
 */
const toExecuteQueryParams = (widgetModel) => {
    return widgetModelTranslator$1.toExecuteQueryParams(widgetModel);
};
/**
 * Translates a {@link WidgetModel} to the parameters for executing a query for the pivot widget.
 *
 * @example
 * ```ts
const widgetModel = await widgetService.getWidgetModel({
  dashboardOid: 'your-dashboard-oid',
  widgetOid: 'your-widget-oid'
});
const executePivotQueryParams = widgetModelTranslator.toExecutePivotQueryParams(widgetModel);
const queryResult = await queryService.executePivotQuery(executeQueryParams);
 * ```
 *
 * Note: this method is supported only for getting pivot query.
 * Use {@link toExecuteQueryParams} instead for getting query parameters for non-pivot widgets.
 */
const toExecutePivotQueryParams = (widgetModel) => {
    return widgetModelTranslator$1.toExecutePivotQueryParams(widgetModel);
};
/**
 * Translates a {@link WidgetModel} to the props for rendering a chart.
 *
 * @example
 * ```html
<csdk-chart
  *ngIf="chartProps"
  [chartType]="chartProps.chartType"
  [dataSet]="chartProps.dataSet"
  [dataOptions]="chartProps.dataOptions"
  [filters]="chartProps.filters"
  [highlights]="chartProps.highlights"
  [styleOptions]="chartProps.styleOptions"
/>
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import {
  type ChartProps
  WidgetService,
  widgetModelTranslator,
} from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  chartProps: ChartProps | null = null;

  constructor(private widgetService: WidgetService) {}

  async ngOnInit(): Promise<void> {
    const widgetModel = await widgetService.getWidgetModel({
      dashboardOid: 'your-dashboard-oid',
      widgetOid: 'your-widget-oid'
    });
    this.chartProps = widgetModelTranslator.toChartProps(widgetModel);
  }
}
 * ```
 *
 * Note: this method is not supported for pivot widgets.
 * Use {@link toPivotTableProps} instead for getting props for the {@link PivotTableComponent}.
 */
function toChartProps(widgetModel) {
    return widgetModelTranslator$1.toChartProps(widgetModel);
}
/**
 * Translates a {@link WidgetModel} to the props for rendering a table.
 *
 * @example
 * ```html
<csdk-table
  *ngIf="tableProps"
  [dataSet]="tableProps.dataSet"
  [dataOptions]="tableProps.dataOptions"
  [filters]="tableProps.filters"
  [styleOptions]="tableProps.styleOptions"
/>
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import {
  type TableProps
  WidgetService,
  widgetModelTranslator,
} from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  tableProps: TableProps | null = null;

  constructor(private widgetService: WidgetService) {}

  async ngOnInit(): Promise<void> {
    const widgetModel = await widgetService.getWidgetModel({
      dashboardOid: 'your-dashboard-oid',
      widgetOid: 'your-widget-oid'
    });
    this.tableProps = widgetModelTranslator.toTableProps(widgetModel);
  }
}
 * ```
 *
 * Note: this method is not supported for chart and pivot widgets.
 * Use {@link toChartProps} instead for getting props for the {@link ChartComponent}.
 * Use {@link toPivotTableProps} instead for getting props for the {@link PivotTableComponent}.
 */
function toTableProps(widgetModel) {
    return widgetModelTranslator$1.toTableProps(widgetModel);
}
/**
 * Translates a {@link WidgetModel} to the props for rendering a pivot table.
 *
 * @example
 * ```html
<csdk-pivot-table
  *ngIf="pivotTableProps"
  [dataSet]="pivotTableProps.dataSet"
  [dataOptions]="pivotTableProps.dataOptions"
  [filters]="pivotTableProps.filters"
  [styleOptions]="pivotTableProps.styleOptions"
/>
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import {
  type PivotTableProps
  WidgetService,
  widgetModelTranslator,
} from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  pivotTableProps: PivotTableProps | null = null;

  constructor(private widgetService: WidgetService) {}

  async ngOnInit(): Promise<void> {
    const widgetModel = await widgetService.getWidgetModel({
      dashboardOid: 'your-dashboard-oid',
      widgetOid: 'your-widget-oid'
    });
    this.pivotTableProps = widgetModelTranslator.toPivotTableProps(widgetModel);
  }
}
 * ```
 *
 * Note: this method is not supported for chart or table widgets.
 * Use {@link toChartProps} instead for getting props for the {@link ChartComponent}.
 * Use {@link toTableProps} instead for getting props for the {@link TableComponent}.
 */
function toPivotTableProps(widgetModel) {
    return widgetModelTranslator$1.toPivotTableProps(widgetModel);
}
/**
 * Translates a {@link WidgetModel} to the props for rendering a chart widget.
 *
 * @example
 * ```html
<csdk-chart-widget
  *ngIf="chartWidgetProps"
  [chartType]="chartWidgetProps.chartType"
  [dataSource]="chartWidgetProps.dataSource"
  [dataOptions]="chartWidgetProps.dataOptions"
  [filters]="chartWidgetProps.filters"
  [highlights]="chartWidgetProps.highlights"
  [styleOptions]="chartWidgetProps.styleOptions"
/>
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import {
  type ChartWidgetProps
  WidgetService,
  widgetModelTranslator,
} from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  chartWidgetProps: ChartWidgetProps | null = null;

  constructor(private widgetService: WidgetService) {}

  async ngOnInit(): Promise<void> {
    const widgetModel = await widgetService.getWidgetModel({
      dashboardOid: 'your-dashboard-oid',
      widgetOid: 'your-widget-oid'
    });
    this.chartWidgetProps = widgetModelTranslator.toChartWidgetProps(widgetModel);
  }
}
 * ```
 *
 * Note: this method is not supported for pivot widgets.
 */
function toChartWidgetProps(widgetModel) {
    return widgetModelTranslator$1.toChartWidgetProps(widgetModel);
}
/**
 * Translates a {@link WidgetModel} to the props for rendering a pivot table widget.
 *
 * @example
 * ```html
<csdk-pivot-table-widget
  *ngIf="pivotWidgetProps"
  [dataSet]="pivotWidgetProps.dataSet"
  [dataOptions]="pivotWidgetProps.dataOptions"
  [filters]="pivotWidgetProps.filters"
  [styleOptions]="pivotWidgetProps.styleOptions"
/>
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import {
  type PivotTableWidgetProps
  WidgetService,
  widgetModelTranslator,
} from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  pivotWidgetProps: PivotTableWidgetProps | null = null;

  constructor(private widgetService: WidgetService) {}

  async ngOnInit(): Promise<void> {
    const widgetModel = await widgetService.getWidgetModel({
      dashboardOid: 'your-dashboard-oid',
      widgetOid: 'your-widget-oid'
    });
    this.pivotWidgetProps = widgetModelTranslator.toPivotTableWidgetProps(widgetModel);
  }
}
 * ```
 *
 * Note: this method is not supported for chart or table widgets.
 * Use {@link toChartWidgetProps} instead for getting props for the {@link ChartWidgetComponent}.
 */
function toPivotTableWidgetProps(widgetModel) {
    return widgetModelTranslator$1.toPivotTableWidgetProps(widgetModel);
}
/**
 * Translates a {@link WidgetModel} to the props for rendering a text widget.
 *
 * @example
 * ```ts
const widgetModel = await widgetService.getWidgetModel({
  dashboardOid: 'your-dashboard-oid',
  widgetOid: 'your-widget-oid'
});
const textWidgetProps = widgetModelTranslator.toTextWidgetProps(widgetModel);
 * ```
 *
 * Note: this method is not supported for chart or pivot widgets.
 * Use {@link toChartWidgetProps} instead for getting props for the {@link ChartWidgetComponent}.
 * Use {@link toPivotTableWidgetProps} instead for getting props for the pivot table widget.
 */
function toTextWidgetProps(widgetModel) {
    return widgetModelTranslator$1.toTextWidgetProps(widgetModel);
}

var widgetModelTranslator = /*#__PURE__*/Object.freeze({
    __proto__: null,
    toChartProps: toChartProps,
    toChartWidgetProps: toChartWidgetProps,
    toExecutePivotQueryParams: toExecutePivotQueryParams,
    toExecuteQueryParams: toExecuteQueryParams,
    toPivotTableProps: toPivotTableProps,
    toPivotTableWidgetProps: toPivotTableWidgetProps,
    toTableProps: toTableProps,
    toTextWidgetProps: toTextWidgetProps
});

/**
 * Public API Surface of @sisense/sdk-ui-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AreaChartComponent, AreaRangeChartComponent, AreamapChartComponent, BarChartComponent, BoxplotChartComponent, ChartComponent, ChartWidgetComponent, ColumnChartComponent, ContextMenuComponent, CriteriaFilterTileComponent, DashboardByIdComponent, DashboardComponent, DashboardService, DateRangeFilterTileComponent, DrilldownBreadcrumbsComponent, DrilldownWidgetComponent, FilterTileComponent, FunnelChartComponent, HierarchyService, IndicatorChartComponent, LineChartComponent, MemberFilterTileComponent, PieChartComponent, PivotTableComponent, PivotTableWidgetComponent, PluginsService, PolarChartComponent, QueryService, RelativeDateFilterTileComponent, SISENSE_CONTEXT_CONFIG_TOKEN, ScatterChartComponent, ScattermapChartComponent, SdkUiModule, SisenseContextService, SunburstChartComponent, THEME_CONFIG_TOKEN, TableComponent, TableWidgetComponent, ThemeService, TrackableService, TreemapChartComponent, WidgetByIdComponent, WidgetComponent, WidgetService, createPluginsContextConnector, createSisenseContextConnector, createThemeContextConnector, dashboardHelpers, dashboardModelTranslator, widgetModelTranslator };
//# sourceMappingURL=sisense-sdk-ui-angular.mjs.map
